@@ -62,24 +62,27 @@ class MenuitemTagHandler:
 
             # TODO maybe use a prefetch for this:
             cursor.execute(cursor.limit_clause(
-            "SELECT a.name, a.type, v.type, v.field_childs, icon.name " \
-            "FROM ir_action a " \
-                "LEFT JOIN ir_action_report report ON (a.id = report.action) "\
-                "LEFT JOIN ir_action_act_window act ON (a.id = act.action) " \
-                "LEFT JOIN ir_action_wizard wizard ON (a.id = wizard.action) "\
-                "LEFT JOIN ir_action_url url ON (a.id = url.action) " \
-                "LEFT JOIN ir_action_act_window_view wv ON " \
-                    "(act.id = wv.act_window) " \
-                "LEFT JOIN ir_ui_view v ON (v.id = wv.view) " \
-                "LEFT JOIN ir_ui_icon icon ON (a.icon = icon.id) " \
-            "WHERE report.id = %s " \
-                "OR act.id = %s " \
-                "OR wizard.id = %s " \
-                "OR url.id = %s " \
-            "ORDER by wv.sequence", 1),
-            (action_id, action_id, action_id, action_id))
+                    "SELECT a.name, a.type, v.type, v.field_childs, icon.name "
+                    "FROM ir_action a "
+                        "LEFT JOIN ir_action_report report "
+                            "ON (a.id = report.action) "
+                        "LEFT JOIN ir_action_act_window act "
+                            "ON (a.id = act.action) "
+                        "LEFT JOIN ir_action_wizard wizard "
+                            "ON (a.id = wizard.action) "
+                        "LEFT JOIN ir_action_url url ON (a.id = url.action) "
+                        "LEFT JOIN ir_action_act_window_view wv ON "
+                            "(act.id = wv.act_window) "
+                        "LEFT JOIN ir_ui_view v ON (v.id = wv.view) "
+                        "LEFT JOIN ir_ui_icon icon ON (a.icon = icon.id) "
+                    "WHERE report.id = %s "
+                        "OR act.id = %s "
+                        "OR wizard.id = %s "
+                        "OR url.id = %s "
+                    "ORDER by wv.sequence", 1),
+                (action_id, action_id, action_id, action_id))
             action_name, action_type, view_type, field_childs, icon_name = \
-                    cursor.fetchone()
+                cursor.fetchone()
 
             values['action'] = '%s,%s' % (action_type, action_id)
 
@@ -158,8 +161,8 @@ class RecordTagHandler:
         # Manage the top level tag
         if name == "record":
             self.model = self.mh.pool.get(attributes["model"])
-            assert self.model, "The model %s does not exist !" % \
-                    (attributes["model"],)
+            assert self.model, ("The model %s does not exist !"
+                % (attributes["model"],))
 
             self.xml_id = attributes["id"]
             self.update = bool(int(attributes.get('update', '0')))
@@ -326,9 +329,9 @@ class Fs2bdAccessor:
             if model.id in self.browserecord[module][model_name]:
                 for cache in Transaction().cursor.cache.values():
                     for cache in (cache, cache.get('_language_cache',
-                        {}).values()):
-                        if model_name in cache \
-                                and model.id in cache[model_name]:
+                                {}).values()):
+                        if (model_name in cache
+                                and model.id in cache[model_name]):
                             cache[model_name][model.id] = {}
             self.browserecord[module][model_name][model.id] = model
 
@@ -337,7 +340,6 @@ class Fs2bdAccessor:
         self.fs2db[module] = {}
         module_data_ids = self.ModelData.search([
                 ('module', '=', module),
-                ('inherit', '=', None),
                 ], order=[('db_id', 'ASC')])
 
         record_ids = {}
@@ -412,10 +414,7 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
             self.sax_parser.parse(source)
         except Exception:
             logging.getLogger("convert").error(
-                "Error while parsing xml file:\n" +\
-                    self.current_state()
-                )
-
+                "Error while parsing xml file:\n" + self.current_state())
             raise
         return self.to_delete
 
@@ -425,7 +424,7 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
 
         if not self.taghandler:
 
-            if  name in self.taghandlerlist:
+            if name in self.taghandlerlist:
                 self.taghandler = self.taghandlerlist[name]
                 self.taghandler.startElement(name, attributes)
 
@@ -472,8 +471,8 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
             module = self.module
 
         if self.fs2db.get(module, xml_id) is None:
-            raise Exception("Reference to %s not found" % \
-                ".".join([module, xml_id]))
+            raise Exception("Reference to %s not found"
+                % ".".join([module, xml_id]))
         return self.fs2db.get(module, xml_id)["db_id"]
 
     @staticmethod
@@ -485,10 +484,7 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
         """
         Model = record.__class__
         # search the field type in the object or in a parent
-        if key in Model._fields:
-            field_type = Model._fields[key]._type
-        else:
-            field_type = Model._inherit_fields[key][2]._type
+        field_type = Model._fields[key]._type
 
         # handle the value regarding to the type
         if field_type == 'many2one':
@@ -520,7 +516,6 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
         # problem when the corresponding recordds will be deleted:
         module_data = self.ModelData.search([
                 ('module', '=', self.module),
-                ('inherit', '=', None),
                 ], order=[('id', 'DESC')])
         return set(rec.fs_id for rec in module_data)
 
@@ -531,15 +526,15 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
             raise Exception('import_record : Argument fs_id is mandatory')
 
         if '.' in fs_id:
-            assert len(fs_id.split('.')) == 2, '"%s" contains too many dots. '\
-                    'file system ids should contain ot most one dot ! ' \
-                    'These are used to refer to other modules data, ' \
-                    'as in module.reference_id' % (fs_id)
+            assert len(fs_id.split('.')) == 2, ('"%s" contains too many dots. '
+                'file system ids should contain ot most one dot ! '
+                'These are used to refer to other modules data, '
+                'as in module.reference_id' % (fs_id))
 
             module, fs_id = fs_id.split('.')
             if not self.fs2db.get(module, fs_id):
-                raise Exception('Reference to %s.%s not found' % \
-                        (module, fs_id))
+                raise Exception('Reference to %s.%s not found'
+                    % (module, fs_id))
 
         Model = self.pool.get(model)
 
@@ -555,11 +550,9 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
 
             # this record is already in the db:
             # XXX maybe use only one call to get()
-            db_id, db_model, mdata_id, old_values = \
-                    [self.fs2db.get(module, fs_id)[x] for x in \
-                    ["db_id", "model", "id", "values"]]
-            inherit_db_ids = {}
-            inherit_mdata_ids = []
+            db_id, db_model, mdata_id, old_values = [
+                self.fs2db.get(module, fs_id)[x]
+                for x in ["db_id", "model", "id", "values"]]
 
             if not old_values:
                 old_values = {}
@@ -575,15 +568,16 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
                     old_values[key] = old_values[key].decode('utf-8')
 
             if model != db_model:
-                raise Exception("This record try to overwrite " \
-                "data with the wrong model: %s (module: %s)" % (fs_id, module))
+                raise Exception("This record try to overwrite "
+                    "data with the wrong model: %s (module: %s)"
+                    % (fs_id, module))
 
             record = self.fs2db.get_browserecord(module, Model.__name__, db_id)
             #Re-create record if it was deleted
             if not record:
                 with Transaction().set_context(
                         module=module, language='en_US'):
-                    record = Model.create(values)
+                    record, = Model.create([values])
 
                 # reset_browsercord
                 self.fs2db.reset_browsercord(
@@ -591,30 +585,6 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
 
                 record = self.fs2db.get_browserecord(
                     module, Model.__name__, record.id)
-                for table, field_name, field in \
-                        Model._inherit_fields.values():
-                    inherit_db_ids[table] = getattr(record, field_name).id
-
-                for table in inherit_db_ids.keys():
-                    data = self.ModelData.search([
-                        ('fs_id', '=', fs_id),
-                        ('module', '=', module),
-                        ('model', '=', table),
-                        ], limit=1)
-                    if data:
-                        self.ModelData.write(data, {
-                            'db_id': inherit_db_ids[table],
-                            'inherit': True,
-                            })
-                    else:
-                        data = self.ModelData.create({
-                            'fs_id': fs_id,
-                            'module': module,
-                            'model': table,
-                            'db_id': inherit_db_ids[table],
-                            'inherit': True,
-                            })
-                    inherit_mdata_ids.append((table, data.id))
 
                 data = self.ModelData.search([
                     ('fs_id', '=', fs_id),
@@ -641,22 +611,13 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
 
                 # we cannot update a field if it was changed by a user...
                 if key not in old_values:
-                    if key in Model._fields:
-                        expected_value = Model._defaults.get(
-                            key, lambda *a: None)()
-                    else:
-                        Inherit = self.pool.get(
-                            Model._inherit_fields[key][0])
-                        expected_value = Inherit._defaults.get(
-                            key, lambda *a: None)()
+                    expected_value = Model._defaults.get(key,
+                        lambda *a: None)()
                 else:
                     expected_value = old_values[key]
 
                 # Migration from 2.0: Reference field change value
-                if key in Model._fields:
-                    field_type = Model._fields[key]._type
-                else:
-                    field_type = Model._inherit_fields[key][2]._type
+                field_type = Model._fields[key]._type
                 if field_type == 'reference':
                     if (expected_value and expected_value.endswith(',0')
                             and not db_field):
@@ -668,9 +629,9 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
                 # False, {} or [])
                 if db_field != expected_value and (db_field or expected_value):
                     logging.getLogger("convert").warning(
-                        "Field %s of %s@%s not updated (id: %s), because "\
-                        "it has changed since the last update" % \
-                        (key, record.id, model, fs_id))
+                        "Field %s of %s@%s not updated (id: %s), because "
+                        "it has changed since the last update"
+                        % (key, record.id, model, fs_id))
                     continue
 
                 # so, the field in the fs and in the db are different,
@@ -686,19 +647,6 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
                 self.fs2db.reset_browsercord(
                     module, Model.__name__, [record.id])
 
-            if not inherit_db_ids:
-                for table, field_name, field in \
-                        Model._inherit_fields.values():
-                    inherit_db_ids[table] = getattr(record, field_name).id
-            if not inherit_mdata_ids:
-                for table in inherit_db_ids.keys():
-                    data, = self.ModelData.search([
-                        ('fs_id', '=', fs_id),
-                        ('module', '=', module),
-                        ('model', '=', table),
-                        ], limit=1)
-                    inherit_mdata_ids.append((table, data.id))
-
             if to_update:
                 # re-read it: this ensure that we store the real value
                 # in the model_data table:
@@ -723,28 +671,13 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
                     'values': str(values),
                     'date_update': datetime.datetime.now(),
                     })
-                for table, inherit_mdata_id in inherit_mdata_ids:
-                    self.ModelData.write(
-                        [self.ModelData(inherit_mdata_id)], {
-                        'fs_id': fs_id,
-                        'model': table,
-                        'module': module,
-                        'db_id': inherit_db_ids[table],
-                        'values': str(values),
-                        'date_update': datetime.datetime.now(),
-                        })
             # reset_browsercord to keep cache memory low
             self.fs2db.reset_browsercord(module, Model.__name__, [record.id])
 
         else:
             # this record is new, create it in the db:
             with Transaction().set_context(module=module, language='en_US'):
-                record = Model.create(values)
-            inherit_db_ids = {}
-
-            for table, field_name, field in (
-                    Model._inherit_fields.values()):
-                inherit_db_ids[table] = getattr(record, field_name).id
+                record, = Model.create([values])
 
             # re-read it: this ensure that we store the real value
             # in the model_data table:
@@ -752,25 +685,14 @@ class TrytondXmlHandler(sax.handler.ContentHandler):
             for key in values:
                 values[key] = self._clean_value(key, record)
 
-            for table in inherit_db_ids.keys():
-                self.ModelData.create({
-                    'fs_id': fs_id,
-                    'model': table,
-                    'module': module,
-                    'db_id': inherit_db_ids[table],
-                    'values': str(values),
-                    'inherit': True,
-                    'noupdate': self.noupdate,
-                    })
-
-            mdata = self.ModelData.create({
-                'fs_id': fs_id,
-                'model': model,
-                'module': module,
-                'db_id': record.id,
-                'values': str(values),
-                'noupdate': self.noupdate,
-                })
+            mdata, = self.ModelData.create([{
+                        'fs_id': fs_id,
+                        'model': model,
+                        'module': module,
+                        'db_id': record.id,
+                        'values': str(values),
+                        'noupdate': self.noupdate,
+                        }])
 
             # update fs2db:
             self.fs2db.set(module, fs_id, {
@@ -821,6 +743,10 @@ def post_import(pool, module, to_delete):
                     'and restart --update=module\n'
                     'Exception: %s' %
                     (db_id, model, tb_s))
+            if 'active' in Model._fields:
+                Model.write([Model(db_id)], {
+                        'active': False,
+                        })
 
     # Clean model_data:
     if mdata_delete:
