@@ -4,8 +4,9 @@ import base64
 import os
 from operator import itemgetter
 from collections import defaultdict
+from functools import partial
 
-from ..model import ModelView, ModelSQL, fields
+from ..model import ModelView, ModelStorage, ModelSQL, fields
 from ..tools import file_open, safe_eval
 from ..backend import TableHandler
 from ..pyson import PYSONEncoder, CONTEXT, PYSON
@@ -15,8 +16,9 @@ from ..cache import Cache
 from ..rpc import RPC
 
 __all__ = [
-    'Action', 'ActionKeyword', 'ActionReport', 'ActionActWindow',
-    'ActionActWindowView', 'ActionWizard', 'ActionURL',
+    'Action', 'ActionKeyword', 'ActionReport',
+    'ActionActWindow', 'ActionActWindowView', 'ActionActWindowDomain',
+    'ActionWizard', 'ActionURL',
     ]
 
 EMAIL_REFKEYS = set(('cc', 'to', 'subject'))
@@ -50,13 +52,19 @@ class Action(ModelSQL, ModelView):
     def default_active():
         return True
 
+    @classmethod
+    def write(cls, actions, values):
+        pool = Pool()
+        super(Action, cls).write(actions, values)
+        pool.get('ir.action.keyword')._get_keyword_cache.clear()
+
     @classmethod
     def get_action_id(cls, action_id):
         pool = Pool()
         with Transaction().set_context(active_test=False):
             if cls.search([
-                ('id', '=', action_id),
-                ]):
+                        ('id', '=', action_id),
+                        ]):
                 return action_id
             for action_type in (
                     'ir.action.report',
@@ -65,17 +73,17 @@ class Action(ModelSQL, ModelView):
                     'ir.action.url',
                     ):
                 Action = pool.get(action_type)
-                action_id2 = Action.search([
+                actions = Action.search([
                     ('id', '=', action_id),
                     ])
-                if action_id2:
-                    action = Action.browse(action_id2[0])
+                if actions:
+                    action, = actions
                     return action.action.id
 
     @classmethod
     def get_action_values(cls, type_, action_ids):
         Action = Pool().get(type_)
-        columns = set(Action._fields.keys() + Action._inherit_fields.keys())
+        columns = set(Action._fields.keys())
         columns.add('icon.rec_name')
         to_remove = ()
         if type_ == 'ir.action.report':
@@ -109,12 +117,10 @@ class ActionKeyword(ModelSQL, ModelView):
     def __setup__(cls):
         super(ActionKeyword, cls).__setup__()
         cls.__rpc__.update({'get_keyword': RPC()})
-        cls._constraints += [
-            ('check_wizard_model', 'wrong_wizard_model'),
-        ]
         cls._error_messages.update({
-            'wrong_wizard_model': 'Wrong wizard model!',
-        })
+                'wrong_wizard_model': ('Wrong wizard model in keyword action '
+                    '"%s".'),
+                })
 
     @classmethod
     def __register__(cls, module_name):
@@ -130,6 +136,12 @@ class ActionKeyword(ModelSQL, ModelView):
     def search_groups(cls, name, clause):
         return [('action.groups',) + tuple(clause[1:])]
 
+    @classmethod
+    def validate(cls, actions):
+        super(ActionKeyword, cls).validate(actions)
+        for action in actions:
+            action.check_wizard_model()
+
     def check_wizard_model(self):
         ActionWizard = Pool().get('ir.action.wizard')
         if self.action.type == 'ir.action.wizard':
@@ -138,8 +150,8 @@ class ActionKeyword(ModelSQL, ModelView):
                 ], limit=1)
             if action_wizard.model:
                 if self.model.__name__ != action_wizard.model:
-                    return False
-        return True
+                    self.raise_user_error('wrong_wizard_model', (
+                            action_wizard.rec_name,))
 
     @staticmethod
     def _convert_vals(vals):
@@ -168,12 +180,14 @@ class ActionKeyword(ModelSQL, ModelView):
         super(ActionKeyword, cls).delete(keywords)
 
     @classmethod
-    def create(cls, vals):
+    def create(cls, vlist):
         ModelView._fields_view_get_cache.clear()
         ModelView._view_toolbar_get_cache.clear()
         cls._get_keyword_cache.clear()
-        vals = cls._convert_vals(vals)
-        return super(ActionKeyword, cls).create(vals)
+        new_vlist = []
+        for vals in vlist:
+            new_vlist.append(cls._convert_vals(vals))
+        return super(ActionKeyword, cls).create(new_vlist)
 
     @classmethod
     def write(cls, keywords, vals):
@@ -217,10 +231,126 @@ class ActionKeyword(ModelSQL, ModelView):
         return keywords
 
 
-class ActionReport(ModelSQL, ModelView):
+class ActionMixin(ModelSQL):
+    _order_name = 'action'
+
+    @classmethod
+    def __setup__(cls):
+        super(ActionMixin, cls).__setup__()
+        for name in dir(Action):
+            field = getattr(Action, name)
+            if (isinstance(field, fields.Field)
+                    and not getattr(cls, name, None)):
+                setattr(cls, name, fields.Function(field, 'get_action',
+                        setter='set_action', searcher='search_action'))
+                default_func = 'default_' + name
+                if getattr(Action, default_func, None):
+                    setattr(cls, default_func,
+                        partial(ActionMixin.default_action, name))
+
+    @staticmethod
+    def default_action(name):
+        pool = Pool()
+        Action = pool.get('ir.action')
+        return getattr(Action, 'default_' + name, None)()
+
+    @classmethod
+    def get_action(cls, ids, names):
+        records = cls.browse(ids)
+        result = {}
+        for name in names:
+            result[name] = values = {}
+            for record in records:
+                value = getattr(record, 'action')
+                convert = lambda v: v
+                if value is not None:
+                    value = getattr(value, name)
+                    if isinstance(value, ModelStorage):
+                        if cls._fields[name]._type == 'reference':
+                            convert = str
+                        else:
+                            convert = int
+                    elif isinstance(value, (list, tuple)):
+                        convert = lambda v: [r.id for r in v]
+                values[record.id] = convert(value)
+        return result
+
+    @classmethod
+    def set_action(cls, records, name, value):
+        pool = Pool()
+        Action = pool.get('ir.action')
+        Action.write([r.action for r in records], {
+                name: value,
+                })
+
+    @classmethod
+    def search_action(cls, name, clause):
+        return [('action.' + name,) + tuple(clause[1:])]
+
+    @classmethod
+    def create(cls, vlist):
+        pool = Pool()
+        Action = pool.get('ir.action')
+        new_records = []
+        for values in vlist:
+            later = {}
+            action_values = {}
+            values = values.copy()
+            for field in values:
+                if field in Action._fields:
+                    action_values[field] = values[field]
+                if hasattr(getattr(cls, field), 'set'):
+                    later[field] = values[field]
+            for field in later:
+                del values[field]
+            action_values['type'] = cls.default_type()
+            cursor = Transaction().cursor
+            if cursor.nextid(cls._table):
+                cursor.setnextid(cls._table, cursor.currid(Action._table))
+            action, = Action.create([action_values])
+            values['action'] = action.id
+            record, = super(ActionMixin, cls).create([values])
+            cursor.execute('UPDATE "' + cls._table + '" SET id = %s '
+                'WHERE id = %s', (action.id, record.id))
+            cursor.update_auto_increment(cls._table, action.id)
+            record = cls(action.id)
+            new_records.append(record)
+            cls.write([record], later)
+        return new_records
+
+    @classmethod
+    def write(cls, records, values):
+        pool = Pool()
+        ActionKeyword = pool.get('ir.action.keyword')
+        super(ActionMixin, cls).write(records, values)
+        ActionKeyword._get_keyword_cache.clear()
+
+    @classmethod
+    def delete(cls, records):
+        pool = Pool()
+        Action = pool.get('ir.action')
+        actions = [x.action for x in records]
+        super(ActionMixin, cls).delete(records)
+        Action.delete(actions)
+
+    @classmethod
+    def copy(cls, records, default=None):
+        pool = Pool()
+        Action = pool.get('ir.action')
+        if default is None:
+            default = {}
+        default = default.copy()
+        new_records = []
+        for record in records:
+            default['action'] = Action.copy([record.action])[0].id
+            new_records.extend(super(ActionMixin, cls).copy([record],
+                    default=default))
+        return new_records
+
+
+class ActionReport(ActionMixin, ModelSQL, ModelView):
     "Action report"
     __name__ = 'ir.action.report'
-    _inherits = {'ir.action': 'action'}
     model = fields.Char('Model')
     report_name = fields.Char('Internal Name', required=True)
     report = fields.Char('Path')
@@ -318,11 +448,8 @@ class ActionReport(ModelSQL, ModelView):
             ('report_name_module_uniq', 'UNIQUE(report_name, module)',
                 'The internal name must be unique by module!'),
         ]
-        cls._constraints += [
-            ('check_email', 'invalid_email'),
-            ]
         cls._error_messages.update({
-                'invalid_email': 'Invalid email!',
+                'invalid_email': 'Invalid email definition on report "%s".',
                 })
 
     @classmethod
@@ -405,6 +532,11 @@ class ActionReport(ModelSQL, ModelView):
     def default_module():
         return Transaction().context.get('module') or ''
 
+    @classmethod
+    def validate(cls, reports):
+        super(ActionReport, cls).validate(reports)
+        cls.check_email(reports)
+
     @classmethod
     def check_email(cls, reports):
         "Check email"
@@ -413,14 +545,14 @@ class ActionReport(ModelSQL, ModelView):
                 try:
                     value = safe_eval(report.email, CONTEXT)
                 except Exception:
-                    return False
+                    value = None
                 if isinstance(value, dict):
                     inkeys = set(value)
                     if not inkeys <= EMAIL_REFKEYS:
-                        return False
+                        cls.raise_user_error('invalid_email', (
+                                report.rec_name,))
                 else:
-                    return False
-        return True
+                    cls.raise_user_error('invalid_email', (report.rec_name,))
 
     @classmethod
     def get_report_content(cls, reports, name):
@@ -484,8 +616,6 @@ class ActionReport(ModelSQL, ModelView):
 
     @classmethod
     def copy(cls, reports, default=None):
-        Action = Pool().get('ir.action')
-
         if default is None:
             default = {}
         default = default.copy()
@@ -496,33 +626,10 @@ class ActionReport(ModelSQL, ModelView):
             if report.report:
                 default['report_content'] = None
             default['report_name'] = report.report_name
-            default['action'] = Action.copy([report.action])[0].id
             new_reports.extend(super(ActionReport, cls).copy([report],
                     default=default))
         return new_reports
 
-    @classmethod
-    def create(cls, vals):
-        later = {}
-        vals = vals.copy()
-        for field in vals:
-            if (field in cls._fields
-                    and hasattr(cls._fields[field], 'set')):
-                later[field] = vals[field]
-        for field in later:
-            del vals[field]
-        cursor = Transaction().cursor
-        if cursor.nextid(cls._table):
-            cursor.setnextid(cls._table, cursor.currid('ir_action'))
-        report = super(ActionReport, cls).create(vals)
-        new_id = report.action.id
-        cursor.execute('UPDATE "' + cls._table + '" SET id = %s ' \
-                'WHERE id = %s', (report.action.id, report.id))
-        cursor.update_auto_increment(cls._table, report.action.id)
-        report = cls(new_id)
-        cls.write([report], later)
-        return report
-
     @classmethod
     def write(cls, reports, vals):
         context = Transaction().context
@@ -532,25 +639,19 @@ class ActionReport(ModelSQL, ModelView):
 
         super(ActionReport, cls).write(reports, vals)
 
-    @classmethod
-    def delete(cls, reports):
-        Action = Pool().get('ir.action')
 
-        actions = [x.action for x in reports]
-        super(ActionReport, cls).delete(reports)
-        Action.delete(actions)
-
-
-class ActionActWindow(ModelSQL, ModelView):
+class ActionActWindow(ActionMixin, ModelSQL, ModelView):
     "Action act window"
     __name__ = 'ir.action.act_window'
-    _inherits = {'ir.action': 'action'}
     domain = fields.Char('Domain Value')
     context = fields.Char('Context Value')
     res_model = fields.Char('Model')
     act_window_views = fields.One2Many('ir.action.act_window.view',
             'act_window', 'Views')
     views = fields.Function(fields.Binary('Views'), 'get_views')
+    act_window_domains = fields.One2Many('ir.action.act_window.domain',
+        'act_window', 'Domains')
+    domains = fields.Function(fields.Binary('Domains'), 'get_domains')
     limit = fields.Integer('Limit', required=True,
             help='Default limit for the list view')
     auto_refresh = fields.Integer('Auto-Refresh', required=True,
@@ -570,16 +671,14 @@ class ActionActWindow(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ActionActWindow, cls).__setup__()
-        cls._constraints += [
-            ('check_views', 'invalid_views'),
-            ('check_domain', 'invalid_domain'),
-            ('check_context', 'invalid_context'),
-        ]
         cls._error_messages.update({
-            'invalid_views': 'Invalid views!',
-            'invalid_domain': 'Invalid domain or search criteria!',
-            'invalid_context': 'Invalid context!',
-        })
+                'invalid_views': ('Invalid view "%(view)s" for action '
+                    '"%(action)s".'),
+                'invalid_domain': ('Invalid domain or search criteria '
+                    '"%(domain)s" on action "%(action)s".'),
+                'invalid_context': ('Invalid context "%(context)s" on action '
+                    '"%(action)s".'),
+                })
         cls.__rpc__.update({
                 'get': RPC(),
                 })
@@ -619,6 +718,13 @@ class ActionActWindow(ModelSQL, ModelView):
     def default_search_value():
         return '[]'
 
+    @classmethod
+    def validate(cls, actions):
+        super(ActionActWindow, cls).validate(actions)
+        cls.check_views(actions)
+        cls.check_domain(actions)
+        cls.check_context(actions)
+
     @classmethod
     def check_views(cls, actions):
         "Check views"
@@ -627,17 +733,28 @@ class ActionActWindow(ModelSQL, ModelView):
                 for act_window_view in action.act_window_views:
                     view = act_window_view.view
                     if view.model != action.res_model:
-                        return False
+                        cls.raise_user_error('invalid_views', {
+                                'view': view.rec_name,
+                                'action': action.rec_name,
+                                })
                     if view.type == 'board':
-                        return False
+                        cls.raise_user_error('invalid_views', {
+                                'view': view.rec_name,
+                                'action': action.rec_name,
+                                })
             else:
                 for act_window_view in action.act_window_views:
                     view = act_window_view.view
                     if view.model:
-                        return False
+                        cls.raise_user_error('invalid_views', {
+                                'view': view.rec_name,
+                                'action': action.rec_name,
+                                })
                     if view.type != 'board':
-                        return False
-        return True
+                        cls.raise_user_error('invalid_views', {
+                                'view': view.rec_name,
+                                'action': action.rec_name,
+                                })
 
     @classmethod
     def check_domain(cls, actions):
@@ -649,18 +766,29 @@ class ActionActWindow(ModelSQL, ModelView):
                 try:
                     value = safe_eval(domain, CONTEXT)
                 except Exception:
-                    return False
+                    cls.raise_user_error('invalid_domain', {
+                            'domain': domain,
+                            'action': action.rec_name,
+                            })
                 if isinstance(value, PYSON):
                     if not value.types() == set([list]):
-                        return False
+                        cls.raise_user_error('invalid_domain', {
+                                'domain': domain,
+                                'action': action.rec_name,
+                                })
                 elif not isinstance(value, list):
-                    return False
+                    cls.raise_user_error('invalid_domain', {
+                            'domain': domain,
+                            'action': action.rec_name,
+                            })
                 else:
                     try:
                         fields.domain_validate(value)
                     except Exception:
-                        return False
-        return True
+                        cls.raise_user_error('invalid_domain', {
+                                'domain': domain,
+                                'action': action.rec_name,
+                                })
 
     @classmethod
     def check_context(cls, actions):
@@ -670,23 +798,40 @@ class ActionActWindow(ModelSQL, ModelView):
                 try:
                     value = safe_eval(action.context, CONTEXT)
                 except Exception:
-                    return False
+                    cls.raise_user_error('invalid_context', {
+                            'context': action.context,
+                            'action': action.rec_name,
+                            })
                 if isinstance(value, PYSON):
                     if not value.types() == set([dict]):
-                        return False
+                        cls.raise_user_error('invalid_context', {
+                                'context': action.context,
+                                'action': action.rec_name,
+                                })
                 elif not isinstance(value, dict):
-                    return False
+                    cls.raise_user_error('invalid_context', {
+                            'context': action.context,
+                            'action': action.rec_name,
+                            })
                 else:
                     try:
                         fields.context_validate(value)
                     except Exception:
-                        return False
-        return True
+                        cls.raise_user_error('invalid_context', {
+                                'context': action.context,
+                                'action': action.rec_name,
+                                })
 
     def get_views(self, name):
         return [(view.view.id, view.view.type)
             for view in self.act_window_views]
 
+    def get_domains(self, name):
+        encoder = PYSONEncoder()
+        return [(domain.name,
+                encoder.encode(safe_eval(domain.domain or '[]', CONTEXT)))
+            for domain in self.act_window_domains]
+
     @classmethod
     def get_pyson(cls, windows, name):
         pysons = {}
@@ -702,58 +847,18 @@ class ActionActWindow(ModelSQL, ModelView):
                     or defaults.get(field, 'None'), CONTEXT))
         return pysons
 
-    @classmethod
-    def create(cls, vals):
-        later = {}
-        vals = vals.copy()
-        for field in vals:
-            if (field in cls._fields
-                    and hasattr(cls._fields[field], 'set')):
-                later[field] = vals[field]
-        for field in later:
-            del vals[field]
-        cursor = Transaction().cursor
-        if cursor.nextid(cls._table):
-            cursor.setnextid(cls._table, cursor.currid('ir_action'))
-        act_window = super(ActionActWindow, cls).create(vals)
-        new_id = act_window.action.id
-        cursor.execute('UPDATE "' + cls._table + '" SET id = %s ' \
-                'WHERE id = %s', (act_window.action.id, act_window.id))
-        cursor.update_auto_increment(cls._table, act_window.action.id)
-        act_window = cls(new_id)
-        cls.write([act_window], later)
-        return act_window
-
-    @classmethod
-    def delete(cls, act_windows):
-        Action = Pool().get('ir.action')
-
-        actions = [x.action.id for x in act_windows]
-        super(ActionActWindow, cls).delete(act_windows)
-        Action.delete(actions)
-
     @classmethod
     def get(cls, xml_id):
-        'Get values from XML id'
+        'Get values from XML id or id'
         pool = Pool()
         ModelData = pool.get('ir.model.data')
         Action = pool.get('ir.action')
-        action_id = ModelData.get_id(*xml_id.split('.'))
+        if '.' in xml_id:
+            action_id = ModelData.get_id(*xml_id.split('.'))
+        else:
+            action_id = int(xml_id)
         return Action.get_action_values(cls.__name__, [action_id])[0]
 
-    @classmethod
-    def copy(cls, actions, default=None):
-        Action = Pool().get('ir.action')
-        if default is None:
-            default = {}
-        default = default.copy()
-        new_actions = []
-        for act_window in actions:
-            default['action'] = Action.copy([act_window.action])[0].id
-            new_actions.extend(super(ActionActWindow, cls).copy([act_window],
-                    default=default))
-        return new_actions
-
 
 class ActionActWindowView(ModelSQL, ModelView):
     "Action act window view"
@@ -778,11 +883,49 @@ class ActionActWindowView(ModelSQL, ModelView):
         # Migration from 1.0 remove multi
         table.drop_column('multi')
 
+    @classmethod
+    def create(cls, vlist):
+        pool = Pool()
+        windows = super(ActionActWindowView, cls).create(vlist)
+        pool.get('ir.action.keyword')._get_keyword_cache.clear()
+        return windows
 
-class ActionWizard(ModelSQL, ModelView):
+    @classmethod
+    def write(cls, windows, values):
+        pool = Pool()
+        super(ActionActWindowView, cls).write(windows, values)
+        pool.get('ir.action.keyword')._get_keyword_cache.clear()
+
+    @classmethod
+    def delete(cls, windows):
+        pool = Pool()
+        super(ActionActWindowView, cls).delete(windows)
+        pool.get('ir.action.keyword')._get_keyword_cache.clear()
+
+
+class ActionActWindowDomain(ModelSQL, ModelView):
+    "Action act window domain"
+    __name__ = 'ir.action.act_window.domain'
+    name = fields.Char('Name', translate=True)
+    sequence = fields.Integer('Sequence', required=True)
+    domain = fields.Char('Domain')
+    act_window = fields.Many2One('ir.action.act_window', 'Action',
+        select=True, required=True, ondelete='CASCADE')
+    active = fields.Boolean('Active')
+
+    @classmethod
+    def __setup__(cls):
+        super(ActionActWindowDomain, cls).__setup__()
+        cls._order.insert(0, ('sequence', 'ASC'))
+
+    @staticmethod
+    def default_active():
+        return True
+
+
+class ActionWizard(ActionMixin, ModelSQL, ModelView):
     "Action wizard"
     __name__ = 'ir.action.wizard'
-    _inherits = {'ir.action': 'action'}
     wiz_name = fields.Char('Wizard name', required=True)
     action = fields.Many2One('ir.action', 'Action', required=True,
             ondelete='CASCADE')
@@ -794,57 +937,10 @@ class ActionWizard(ModelSQL, ModelView):
     def default_type():
         return 'ir.action.wizard'
 
-    @classmethod
-    def create(cls, vals):
-        later = {}
-        vals = vals.copy()
-        for field in vals:
-            if (field in cls._fields
-                    and hasattr(cls._fields[field], 'set')):
-                later[field] = vals[field]
-        for field in later:
-            del vals[field]
-        cursor = Transaction().cursor
-        if cursor.nextid(cls._table):
-            cursor.setnextid(cls._table, cursor.currid('ir_action'))
-        wizard = super(ActionWizard, cls).create(vals)
-        new_id = wizard.action.id
-        cursor.execute('UPDATE "' + cls._table + '" SET id = %s ' \
-                'WHERE id = %s', (wizard.action.id, wizard.id))
-        cursor.update_auto_increment(cls._table, wizard.action.id)
-        wizard = cls(new_id)
-        cls.write([wizard], later)
-        return wizard
 
-    @classmethod
-    def delete(cls, wizards):
-        pool = Pool()
-        Action = pool.get('ir.action')
-
-        actions = [x.action.id for x in wizards]
-
-        super(ActionWizard, cls).delete(wizards)
-        Action.delete(actions)
-
-    @classmethod
-    def copy(cls, wizards, default=None):
-        Action = Pool().get('ir.action')
-
-        if default is None:
-            default = {}
-        default = default.copy()
-        new_wizards = []
-        for wizard in wizards:
-            default['action'] = Action.copy([wizard.action])[0].id
-            new_wizards.extend(super(ActionWizard, cls).copy([wizard],
-                    default=default))
-        return new_wizards
-
-
-class ActionURL(ModelSQL, ModelView):
+class ActionURL(ActionMixin, ModelSQL, ModelView):
     "Action URL"
     __name__ = 'ir.action.url'
-    _inherits = {'ir.action': 'action'}
     url = fields.Char('Action Url', required=True)
     action = fields.Many2One('ir.action', 'Action', required=True,
             ondelete='CASCADE')
@@ -856,49 +952,3 @@ class ActionURL(ModelSQL, ModelView):
     @staticmethod
     def default_target():
         return 'new'
-
-    @classmethod
-    def create(cls, vals):
-        later = {}
-        vals = vals.copy()
-        for field in vals:
-            if (field in cls._fields
-                    and hasattr(cls._fields[field], 'set')):
-                later[field] = vals[field]
-        for field in later:
-            del vals[field]
-        cursor = Transaction().cursor
-        if cursor.nextid(cls._table):
-            cursor.setnextid(cls._table, cursor.currid('ir_action'))
-        url = super(ActionURL, cls).create(vals)
-        new_id = url.action.id
-        cursor.execute('UPDATE "' + cls._table + '" SET id = %s ' \
-                'WHERE id = %s', (url.action.id, url.id))
-        cursor.update_auto_increment(cls._table, url.action.id)
-        url = cls(new_id)
-        cls.write([url], later)
-        return url
-
-    @classmethod
-    def delete(cls, urls):
-        pool = Pool()
-        Action = pool.get('ir.action')
-
-        actions = [x.action for x in urls]
-
-        super(ActionURL, cls).delete(urls)
-        Action.delete(actions)
-
-    @classmethod
-    def copy(cls, urls, default=None):
-        Action = Pool().get('ir.action')
-
-        if default is None:
-            default = {}
-        default = default.copy()
-        new_urls = []
-        for url in urls:
-            default['action'] = Action.copy([url.action])[0].id
-            new_urls.extend(super(ActionURL, cls).copy([url],
-                    default=default))
-        return new_urls
