@@ -6,7 +6,7 @@ from dateutil.relativedelta import relativedelta
 import traceback
 import sys
 import logging
-from ..config import CONFIG
+
 from ..model import ModelView, ModelSQL, fields
 from ..tools import safe_eval
 from ..transaction import Transaction
@@ -39,12 +39,12 @@ class Cron(ModelSQL, ModelView):
     active = fields.Boolean('Active', select=True)
     interval_number = fields.Integer('Interval Number', required=True)
     interval_type = fields.Selection([
-       ('minutes', 'Minutes'),
-       ('hours', 'Hours'),
-       ('days', 'Days'),
-       ('weeks', 'Weeks'),
-       ('months', 'Months'),
-       ], 'Interval Unit')
+            ('minutes', 'Minutes'),
+            ('hours', 'Hours'),
+            ('days', 'Days'),
+            ('weeks', 'Weeks'),
+            ('months', 'Months'),
+            ], 'Interval Unit')
     number_calls = fields.Integer('Number of Calls', select=1, required=True,
        help=('Number of times the function is called, a negative '
            'number indicates that the function will always be '
@@ -135,9 +135,9 @@ class Cron(ModelSQL, ModelView):
             'body': body,
             'date_sent': datetime.datetime.now(),
             'references': [
-                ('create', {
-                    'reference': '%s,%s' % (cls.__name__, cron.id),
-                }),
+                ('create', [{
+                            'reference': '%s,%s' % (cls.__name__, cron.id),
+                            }]),
             ],
             'state': 'waiting',
             'trigger_date': datetime.datetime.now(),
@@ -147,6 +147,7 @@ class Cron(ModelSQL, ModelView):
     @classmethod
     def _callback(cls, cron):
         pool = Pool()
+        Config = pool.get('ir.configuration')
         try:
             args = (cron.args or []) and safe_eval(cron.args)
             Model = pool.get(cron.model)
@@ -158,11 +159,11 @@ class Cron(ModelSQL, ModelView):
             Request = pool.get('res.request')
             req_user = cron.request_user
             language = (req_user.language.code if req_user.language
-                    else CONFIG['language'])
+                    else Config.get_language())
             with contextlib.nested(Transaction().set_user(cron.user.id),
                     Transaction().set_context(language=language)):
                 values = cls._get_request_values(cron)
-                Request.create(values)
+                Request.create([values])
             Transaction().cursor.commit()
 
     @classmethod
