@@ -2,6 +2,8 @@
 #this repository contains the full copyright notices and license terms.
 import datetime
 import re
+import heapq
+
 from ..model import ModelView, ModelSQL, fields
 from ..report import Report
 from ..wizard import Wizard, StateView, StateAction, Button
@@ -10,6 +12,11 @@ from ..cache import Cache
 from ..pool import Pool
 from ..pyson import Bool, Eval
 from ..rpc import RPC
+from ..backend import TableHandler
+try:
+    from ..tools.StringMatcher import StringMatcher
+except ImportError:
+    from difflib import SequenceMatcher as StringMatcher
 
 __all__ = [
     'Model', 'ModelField', 'ModelAccess', 'ModelFieldAccess', 'ModelButton',
@@ -39,6 +46,7 @@ class Model(ModelSQL, ModelView):
         depends=['module'])
     module = fields.Char('Module',
        help="Module in which this model is defined", readonly=True)
+    global_search_p = fields.Boolean('Global Search')
     fields = fields.One2Many('ir.model.field', 'model', 'Fields',
        required=True)
 
@@ -48,18 +56,22 @@ class Model(ModelSQL, ModelView):
         cls._sql_constraints += [
             ('model_uniq', 'UNIQUE(model)',
                 'The model must be unique!'),
-        ]
-        cls._constraints += [
-            ('check_module', 'invalid_module'),
-        ]
+            ]
         cls._error_messages.update({
-            'invalid_module': 'Module Name must be a python identifier!',
-        })
+                'invalid_module': ('Module name "%s" is not a valid python '
+                    'identifier.'),
+                })
         cls._order.insert(0, ('model', 'ASC'))
         cls.__rpc__.update({
                 'list_models': RPC(),
+                'global_search': RPC(),
                 })
 
+    @classmethod
+    def validate(cls, models):
+        super(Model, cls).validate(models)
+        cls.check_module(models)
+
     @classmethod
     def check_module(cls, models):
         '''
@@ -67,8 +79,7 @@ class Model(ModelSQL, ModelView):
         '''
         for model in models:
             if model.module and not IDENTIFIER.match(model.module):
-                return False
-        return True
+                cls.raise_user_error('invalid_module', (model.rec_name,))
 
     @classmethod
     def list_models(cls):
@@ -82,10 +93,10 @@ class Model(ModelSQL, ModelView):
             return [m.model for m in models]
 
     @classmethod
-    def create(cls, vals):
+    def create(cls, vlist):
         pool = Pool()
         Property = pool.get('ir.property')
-        res = super(Model, cls).create(vals)
+        res = super(Model, cls).create(vlist)
         # Restart the cache of models_get
         Property._models_get_cache.clear()
         return res
@@ -106,6 +117,44 @@ class Model(ModelSQL, ModelView):
         # Restart the cache of models_get
         Property._models_get_cache.clear()
 
+    @classmethod
+    def global_search(cls, text, limit, menu='ir.ui.menu'):
+        """
+        Search on models for text including menu
+        Returns a list of tuple (ratio, model, model_name, id, rec_name, icon)
+        The size of the list is limited to limit
+        """
+        pool = Pool()
+        ModelAccess = pool.get('ir.model.access')
+
+        if not limit > 0:
+            raise ValueError('limit must be > 0: %r' % (limit,))
+
+        models = cls.search(['OR',
+                ('global_search_p', '=', True),
+                ('model', '=', menu),
+                ])
+        access = ModelAccess.get_access([m.model for m in models])
+        s = StringMatcher()
+        if isinstance(text, str):
+            text = text.decode('utf-8')
+        s.set_seq2(text)
+
+        def generate():
+            for model in models:
+                if not access[model.model]['read']:
+                    continue
+                Model = pool.get(model.model)
+                if not hasattr(Model, 'search_global'):
+                    continue
+                for id_, rec_name, icon in Model.search_global(text):
+                    if isinstance(rec_name, str):
+                        rec_name = rec_name.decode('utf-8')
+                    s.set_seq1(rec_name)
+                    yield (s.ratio(), model.model, model.rec_name,
+                        id_, rec_name, icon)
+        return heapq.nlargest(int(limit), generate())
+
 
 class ModelField(ModelSQL, ModelView):
     "Model field"
@@ -137,8 +186,8 @@ class ModelField(ModelSQL, ModelView):
             'readonly': Bool(Eval('module')),
             },
         depends=['module'])
-    groups = fields.Many2Many('ir.model.field-res.group', 'field_id',
-            'group_id', 'Groups')
+    groups = fields.Many2Many('ir.model.field-res.group', 'field',
+            'group', 'Groups')
     help = fields.Text('Help', translate=True, loading='lazy',
         states={
             'readonly': Bool(Eval('module')),
@@ -153,13 +202,11 @@ class ModelField(ModelSQL, ModelView):
         cls._sql_constraints += [
             ('name_model_uniq', 'UNIQUE(name, model)',
                 'The field name in model must be unique!'),
-        ]
-        cls._constraints += [
-            ('check_name', 'invalid_name'),
-        ]
+            ]
         cls._error_messages.update({
-            'invalid_name': 'Model Field Name must be a python identifier!',
-        })
+                'invalid_name': ('Model Field name "%s" is not a valid python '
+                    'identifier.'),
+                })
         cls._order.insert(0, ('name', 'ASC'))
 
     @staticmethod
@@ -170,6 +217,11 @@ class ModelField(ModelSQL, ModelView):
     def default_field_description():
         return 'No description available'
 
+    @classmethod
+    def validate(cls, fields):
+        super(ModelField, cls).validate(fields)
+        cls.check_name(fields)
+
     @classmethod
     def check_name(cls, fields):
         '''
@@ -177,8 +229,7 @@ class ModelField(ModelSQL, ModelView):
         '''
         for field in fields:
             if not IDENTIFIER.match(field.name):
-                return False
-        return True
+                cls.raise_user_error('invalid_name', (field.name,))
 
     @classmethod
     def read(cls, ids, fields_names=None):
@@ -212,8 +263,8 @@ class ModelField(ModelSQL, ModelView):
                     model_ids.add(rec['model'])
             model_ids = list(model_ids)
             cursor = Transaction().cursor
-            cursor.execute('SELECT id, model FROM ir_model WHERE id IN ' \
-                    '(' + ','.join(('%s',) * len(model_ids)) + ')', model_ids)
+            cursor.execute('SELECT id, model FROM ir_model WHERE id IN '
+                '(' + ','.join(('%s',) * len(model_ids)) + ')', model_ids)
             id2model = dict(cursor.fetchall())
 
             trans_args = []
@@ -272,10 +323,6 @@ class ModelAccess(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ModelAccess, cls).__setup__()
-        cls._sql_constraints += [
-            ('model_group_uniq', 'UNIQUE("model", "group")',
-                'Only one record by model and group is allowed!'),
-        ]
         cls._error_messages.update({
             'read': 'You can not read this document! (%s)',
             'write': 'You can not write in this document! (%s)',
@@ -286,6 +333,17 @@ class ModelAccess(ModelSQL, ModelView):
                 'get_access': RPC(),
                 })
 
+    @classmethod
+    def __register__(cls, module_name):
+        cursor = Transaction().cursor
+
+        super(ModelAccess, cls).__register__(module_name)
+
+        table = TableHandler(cursor, cls, module_name)
+
+        # Migration from 2.6 (model, group) no more unique
+        table.drop_constraint('model_group_uniq')
+
     @staticmethod
     def check_xml_record(accesses, values):
         return True
@@ -353,7 +411,7 @@ class ModelAccess(ModelSQL, ModelView):
     def check(cls, model_name, mode='read', raise_exception=True):
         'Check access for model_name and mode'
         assert mode in ['read', 'write', 'create', 'delete'], \
-                'Invalid access mode for security'
+            'Invalid access mode for security'
         if Transaction().user == 0:
             return True
 
@@ -373,8 +431,8 @@ class ModelAccess(ModelSQL, ModelView):
         ModelView._fields_view_get_cache.clear()
 
     @classmethod
-    def create(cls, vals):
-        res = super(ModelAccess, cls).create(vals)
+    def create(cls, vlist):
+        res = super(ModelAccess, cls).create(vlist)
         # Restart the cache
         cls._get_access_cache.clear()
         ModelView._fields_view_get_cache.clear()
@@ -405,15 +463,22 @@ class ModelFieldAccess(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ModelFieldAccess, cls).__setup__()
-        cls._sql_constraints += [
-            ('field_group_uniq', 'UNIQUE("field", "group")',
-                'Only one record by field and group is allowed!'),
-        ]
         cls._error_messages.update({
             'read': 'You can not read the field! (%s.%s)',
             'write': 'You can not write on the field! (%s.%s)',
             })
 
+    @classmethod
+    def __register__(cls, module_name):
+        cursor = Transaction().cursor
+
+        super(ModelFieldAccess, cls).__register__(module_name)
+
+        table = TableHandler(cursor, cls, module_name)
+
+        # Migration from 2.6 (field, group) no more unique
+        table.drop_constraint('field_group_uniq')
+
     @staticmethod
     def check_xml_record(field_accesses, values):
         return True
@@ -434,6 +499,51 @@ class ModelFieldAccess(ModelSQL, ModelView):
     def default_perm_delete():
         return True
 
+    @classmethod
+    def get_access(cls, models):
+        'Return fields access for models'
+        pool = Pool()
+        Model = pool.get('ir.model')
+        ModelField = pool.get('ir.model.field')
+        cursor = Transaction().cursor
+        user = Transaction().user
+
+        accesses = {}
+        for model in models:
+            maccesses = cls._get_access_cache.get((user, model))
+            if maccesses is None:
+                break
+            accesses[model] = maccesses
+        else:
+            return accesses
+
+        default = {}
+        accesses = dict((m, default) for m in models)
+        cursor.execute(('SELECT '
+                    'm.model, '
+                    'f.name, '
+                    'MAX(CASE WHEN a.perm_read THEN 1 ELSE 0 END), '
+                    'MAX(CASE WHEN a.perm_write THEN 1 ELSE 0 END), '
+                    'MAX(CASE WHEN a.perm_create THEN 1 ELSE 0 END), '
+                    'MAX(CASE WHEN a.perm_delete THEN 1 ELSE 0 END) '
+                'FROM "%s" AS a '
+                'JOIN "%s" AS f '
+                    'ON (a.field = f.id) '
+                'JOIN "%s" AS m '
+                    'ON (f.model = m.id) '
+                'LEFT JOIN "res_user-res_group" AS gu '
+                    'ON (gu."group" = a."group") '
+                'WHERE m.model IN (' + ','.join(('%%s',) * len(models)) + ') '
+                    'AND (gu."user" = %%s OR a."group" IS NULL) '
+                'GROUP BY m.model, f.name')
+            % (cls._table, ModelField._table, Model._table),
+            list(models) + [Transaction().user])
+        for m, f, r, w, c, d in cursor.fetchall():
+            accesses[m][f] = {'read': r, 'write': w, 'create': c, 'delete': d}
+        for model, maccesses in accesses.iteritems():
+            cls._get_access_cache.set((user, model), maccesses)
+        return accesses
+
     @classmethod
     def check(cls, model_name, fields, mode='read', raise_exception=True,
             access=False):
@@ -447,33 +557,8 @@ class ModelFieldAccess(ModelSQL, ModelView):
                 return dict((x, True) for x in fields)
             return True
 
-        pool = Pool()
-        Model = pool.get('ir.model')
-        ModelField = pool.get('ir.model.field')
-        UserGroup = pool.get('res.user-res.group')
-
-        cursor = Transaction().cursor
-        key = (model_name, mode, access, Transaction().user)
-        accesses = cls._get_access_cache.get(key)
-
-        if accesses is None:
-            cursor.execute('SELECT f.name, '
-                'MAX(CASE WHEN a.perm_%s THEN 1 ELSE 0 END) '
-                'FROM "%s" AS a '
-                'JOIN "%s" AS f '
-                    'ON (a.field = f.id) '
-                'JOIN "%s" AS m '
-                    'ON (f.model = m.id) '
-                'LEFT JOIN "%s" AS gu '
-                    'ON (gu."group" = a."group") '
-                'WHERE m.model = %%s '
-                    'AND (gu."user" = %%s OR a."group" IS NULL) '
-                'GROUP BY f.name'
-                % (mode, cls._table, ModelField._table,
-                    Model._table, UserGroup._table), (model_name,
-                    Transaction().user))
-            accesses = dict(cursor.fetchall())
-            cls._get_access_cache.set(key, accesses)
+        accesses = dict((f, a[mode])
+            for f, a in cls.get_access([model_name])[model_name].iteritems())
         if access:
             return accesses
         for field in fields:
@@ -492,8 +577,8 @@ class ModelFieldAccess(ModelSQL, ModelView):
         ModelView._fields_view_get_cache.clear()
 
     @classmethod
-    def create(cls, vals):
-        res = super(ModelFieldAccess, cls).create(vals)
+    def create(cls, vlist):
+        res = super(ModelFieldAccess, cls).create(vlist)
         # Restart the cache
         cls._get_access_cache.clear()
         ModelView._fields_view_get_cache.clear()
@@ -527,8 +612,8 @@ class ModelButton(ModelSQL, ModelView):
         cls._order.insert(0, ('model', 'ASC'))
 
     @classmethod
-    def create(cls, values):
-        result = super(ModelButton, cls).create(values)
+    def create(cls, vlist):
+        result = super(ModelButton, cls).create(vlist)
         # Restart the cache for get_groups
         cls._groups_cache.clear()
         return result
@@ -581,7 +666,6 @@ class ModelData(ModelSQL, ModelView):
     date_update = fields.DateTime('Update Date')
     date_init = fields.DateTime('Init Date')
     values = fields.Text('Values')
-    inherit = fields.Boolean('Inherit')
     noupdate = fields.Boolean('No Update')
     _get_id_cache = Cache('ir_model_data.get_id', context=False)
 
@@ -593,14 +677,24 @@ class ModelData(ModelSQL, ModelView):
                 'The triple (fs_id, module, model) must be unique!'),
         ]
 
+    @classmethod
+    def __register__(cls, module_name):
+        cursor = Transaction().cursor
+
+        super(ModelData, cls).__register__(module_name)
+
+        table = TableHandler(cursor, cls, module_name)
+
+        # Migration from 2.6: remove inherit
+        if table.column_exist('inherit'):
+            cursor.execute('DELETE FROM "' + cls._table + '" '
+                'WHERE inherit = %s', (True,))
+            table.drop_column('inherit', True)
+
     @staticmethod
     def default_date_init():
         return datetime.datetime.now()
 
-    @staticmethod
-    def default_inherit():
-        return False
-
     @staticmethod
     def default_noupdate():
         return False
@@ -623,7 +717,6 @@ class ModelData(ModelSQL, ModelView):
         data = cls.search([
             ('module', '=', module),
             ('fs_id', '=', fs_id),
-            ('inherit', '=', False),
             ], limit=1)
         if not data:
             raise Exception("Reference to %s not found"
