@@ -2,13 +2,14 @@
 #this repository contains the full copyright notices and license terms.
 import contextlib
 import time
+import datetime
+
 from ..model import ModelView, ModelSQL, fields
 from ..tools import safe_eval
-from ..pyson import Eval
 from ..transaction import Transaction
 from ..cache import Cache
-from ..const import OPERATORS
 from ..pool import Pool
+from ..backend import TableHandler
 
 __all__ = [
     'RuleGroup', 'Rule',
@@ -20,18 +21,17 @@ class RuleGroup(ModelSQL, ModelView):
     __name__ = 'ir.rule.group'
     name = fields.Char('Name', select=True)
     model = fields.Many2One('ir.model', 'Model', select=True,
-            required=True)
+        required=True)
     global_p = fields.Boolean('Global', select=True,
-            help="Make the rule global \n" \
-                    "so every users must follow this rule")
+        help="Make the rule global \nso every users must follow this rule")
     default_p = fields.Boolean('Default', select=True,
-            help="Add this rule to all users by default")
+        help="Add this rule to all users by default")
     rules = fields.One2Many('ir.rule', 'rule_group', 'Tests',
-            help="The rule is satisfied if at least one test is True")
+        help="The rule is satisfied if at least one test is True")
     groups = fields.Many2Many('ir.rule.group-res.group',
-            'rule_group', 'group', 'Groups')
+        'rule_group', 'group', 'Groups')
     users = fields.Many2Many('ir.rule.group-res.user',
-            'rule_group', 'user', 'Users')
+        'rule_group', 'user', 'Users')
     perm_read = fields.Boolean('Read Access')
     perm_write = fields.Boolean('Write Access')
     perm_create = fields.Boolean('Create Access')
@@ -79,8 +79,8 @@ class RuleGroup(ModelSQL, ModelView):
         Pool().get('ir.rule')._domain_get_cache.clear()
 
     @classmethod
-    def create(cls, vals):
-        res = super(RuleGroup, cls).create(vals)
+    def create(cls, vlist):
+        res = super(RuleGroup, cls).create(vlist)
         # Restart the cache on the domain_get method of ir.rule
         Pool().get('ir.rule')._domain_get_cache.clear()
         return res
@@ -96,76 +96,67 @@ class Rule(ModelSQL, ModelView):
     "Rule"
     __name__ = 'ir.rule'
     _rec_name = 'field'
-    field = fields.Many2One('ir.model.field', 'Field',
-        domain=[('model', '=', Eval('_parent_rule_group', {}).get('model'))],
-        select=True, required=True)
-    operator = fields.Selection([(x, x) for x in OPERATORS], 'Operator',
-        required=True, translate=False)
-    operand = fields.Selection('get_operand', 'Operand', required=True)
     rule_group = fields.Many2One('ir.rule.group', 'Group', select=True,
        required=True, ondelete="CASCADE")
+    domain = fields.Char('Domain', required=True,
+        help='Domain is evaluated with "user" as the current user')
     _domain_get_cache = Cache('ir_rule.domain_get')
 
+    @classmethod
+    def __setup__(cls):
+        super(Rule, cls).__setup__()
+        cls._error_messages.update({
+                'invalid_domain': 'Invalid domain in rule "%s".',
+                })
+
     @classmethod
     def __register__(cls, module_name):
-        cursor = Transaction().cursor
-
         super(Rule, cls).__register__(module_name)
+        table = TableHandler(Transaction().cursor, cls, module_name)
 
-        # Migration from 2.0: rename operator '<>' into '!='
-        cursor.execute('UPDATE "%s" '
-            'SET operator = %%s '
-            'WHERE operator = %%s' % cls._table, ('!=', '<>'))
+        # Migration from 2.6: replace field, operator and operand by domain
+        table.not_null_action('field', action='remove')
+        table.not_null_action('operator', action='remove')
+        table.not_null_action('operand', action='remove')
 
     @classmethod
-    def _operand_get(cls, obj_name='', level=3, recur=None, root_tech='',
-            root=''):
-        res = {}
-        if not obj_name:
-            obj_name = 'res.user'
-        res.update({"False": "False", "True": "True", "User": "user.id"})
-        if not recur:
-            recur = []
-        with Transaction().set_context(language='en_US'):
-            obj_fields = Pool().get(obj_name).fields_get()
-        key = obj_fields.keys()
-        key.sort()
-        for k in key:
+    def validate(cls, rules):
+        super(Rule, cls).validate(rules)
+        cls.check_domain(rules)
 
-            if obj_fields[k]['type'] in ('many2one'):
-                res[root + '/' + obj_fields[k]['string']] = (
-                    '(%s.%s.id if %s.%s else None)'
-                    % (root_tech, k, root_tech, k))
-
-            elif obj_fields[k]['type'] in ('many2many', 'one2many'):
-                res[root + '/' + obj_fields[k]['string']] = (
-                    '[x.id for x in (%s.%s or [])]'
-                    % (root_tech, k))
+    @classmethod
+    def check_domain(cls, rules):
+        ctx = cls._get_context()
+        for rule in rules:
+            try:
+                value = safe_eval(rule.domain, ctx)
+            except Exception:
+                return False
+            if not isinstance(value, list):
+                cls.raise_user_error('invalid_domain', (rule.rec_name,))
             else:
-                res[root + '/' + obj_fields[k]['string']] = \
-                    root_tech + '.' + k
+                try:
+                    fields.domain_validate(value)
+                except Exception:
+                    cls.raise_user_error('invalid_domain', (rule.rec_name,))
 
-            if (obj_fields[k]['type'] in recur) and (level > 0):
-                res.update(cls._operand_get(obj_fields[k]['relation'],
-                        level - 1, recur,
-                        '(%s.%s if %s else None)' % (root_tech,  k, root_tech),
-                        root + '/' + obj_fields[k]['string']))
-
-        return res
-
-    @classmethod
-    def get_operand(cls):
-        res = []
-        operands = cls._operand_get('res.user', level=1, recur=['many2one'],
-                root_tech='user', root='User')
-        for i in operands.keys():
-            res.append((i, i))
-        return res
+    @staticmethod
+    def _get_context():
+        User = Pool().get('res.user')
+        user_id = Transaction().user
+        with Transaction().set_user(0, set_context=True):
+            user = User(user_id)
+        return {
+            'user': user,
+            'current_date': datetime.datetime.today(),
+            'time': time,
+            'context': Transaction().context,
+            }
 
     @classmethod
     def domain_get(cls, model_name, mode='read'):
         assert mode in ['read', 'write', 'create', 'delete'], \
-                'Invalid domain mode for security'
+            'Invalid domain mode for security'
 
         # root user above constraint
         if Transaction().user == 0:
@@ -185,7 +176,6 @@ class Rule(ModelSQL, ModelView):
         RuleGroup_User = pool.get('ir.rule.group-res.user')
         RuleGroup_Group = pool.get('ir.rule.group-res.group')
         User_Group = pool.get('res.user-res.group')
-        User = pool.get('res.user')
 
         cursor = Transaction().cursor
         cursor.execute('SELECT r.id FROM "' + cls._table + '" r '
@@ -213,22 +203,15 @@ class Rule(ModelSQL, ModelView):
         obj = pool.get(model_name)
         clause = {}
         clause_global = {}
-        operand2query = cls._operand_get('res.user', level=1,
-                recur=['many2one'], root_tech='user', root='User')
         user_id = Transaction().user
-        with Transaction().set_user(0, set_context=True):
-            user = User(user_id)
+        ctx = cls._get_context()
         # Use root user without context to prevent recursion
         with contextlib.nested(Transaction().set_user(0),
                 Transaction().set_context(user=0)):
             for rule in cls.browse(ids):
-                dom = safe_eval("[('%s', '%s', %s)]" % \
-                        (rule.field.name, rule.operator,
-                            operand2query[rule.operand]), {
-                                'user': user,
-                                'time': time,
-                                })
-
+                assert rule.domain, ('Rule domain empty,'
+                    'check if migration was done')
+                dom = safe_eval(rule.domain, ctx)
                 if rule.rule_group.global_p:
                     clause_global.setdefault(rule.rule_group.id, ['OR'])
                     clause_global[rule.rule_group.id].append(dom)
@@ -236,22 +219,19 @@ class Rule(ModelSQL, ModelView):
                     clause.setdefault(rule.rule_group.id, ['OR'])
                     clause[rule.rule_group.id].append(dom)
 
-        query = ''
-        val = []
-
         # Test if there is no rule_group that have no rule
-        cursor.execute('SELECT g.id FROM "' + RuleGroup._table + '" g ' \
-                'JOIN "' + Model._table + '" m ON (g.model = m.id) ' \
-            'WHERE m.model = %s ' \
-                'AND (g.id NOT IN (SELECT rule_group ' \
-                        'FROM "' + cls._table + '")) ' \
-                'AND (g.id IN (SELECT rule_group ' \
-                        'FROM "' + RuleGroup_User._table + '" ' \
-                        'WHERE "user" = %s ' \
-                        'UNION SELECT rule_group ' \
-                        'FROM "' + RuleGroup_Group._table + '" g_rel ' \
-                            'JOIN "' + User_Group._table + '" u_rel ' \
-                                'ON g_rel."group" = u_rel."group" ' \
+        cursor.execute('SELECT g.id FROM "' + RuleGroup._table + '" g '
+                'JOIN "' + Model._table + '" m ON (g.model = m.id) '
+            'WHERE m.model = %s '
+                'AND (g.id NOT IN (SELECT rule_group '
+                        'FROM "' + cls._table + '")) '
+                'AND (g.id IN (SELECT rule_group '
+                        'FROM "' + RuleGroup_User._table + '" '
+                        'WHERE "user" = %s '
+                        'UNION SELECT rule_group '
+                        'FROM "' + RuleGroup_Group._table + '" g_rel '
+                            'JOIN "' + User_Group._table + '" u_rel '
+                                'ON g_rel."group" = u_rel."group" '
                         'WHERE u_rel."user" = %s))',
             (model_name, user_id, user_id))
         fetchone = cursor.fetchone()
@@ -267,7 +247,11 @@ class Rule(ModelSQL, ModelView):
             clause_global.insert(0, 'AND')
             clause = ['AND', clause_global, clause]
 
-        query, val, _, _ = obj.search_domain(clause, active_test=False)
+        # Use root to prevent infinite recursion
+        with contextlib.nested(Transaction().set_user(0),
+                Transaction().set_context(active_test=False, user=0)):
+            query, val = obj.search(clause, order=[], query_string=True)
+        query = '("%s".id IN (%s))' % (obj._table, query)
 
         cls._domain_get_cache.set(key, (query, val))
         return query, val
@@ -279,8 +263,8 @@ class Rule(ModelSQL, ModelView):
         cls._domain_get_cache.clear()
 
     @classmethod
-    def create(cls, vals):
-        res = super(Rule, cls).create(vals)
+    def create(cls, vlist):
+        res = super(Rule, cls).create(vlist)
         # Restart the cache on the domain_get method of ir.rule
         cls._domain_get_cache.clear()
         return res
