@@ -75,10 +75,7 @@ class Many2Many(Field):
             order = self.order
 
         Relation = Pool().get(self.relation_name)
-        if self.origin in Relation._fields:
-            origin_field = Relation._fields[self.origin]
-        else:
-            origin_field = Relation._inherit_fields[self.origin][2]
+        origin_field = Relation._fields[self.origin]
 
         relations = []
         for i in range(0, len(ids), Transaction().cursor.IN_MAX):
@@ -102,7 +99,7 @@ class Many2Many(Field):
         Set the values.
 
         values: A list of tuples:
-            (``create``, ``{<field name>: value}``),
+            (``create``, ``[{<field name>: value}, ...]``),
             (``write``, ``<ids>``, ``{<field name>: value}``),
             (``delete``, ``<ids>``),
             (``delete_all``),
@@ -116,11 +113,7 @@ class Many2Many(Field):
             return
         Relation = pool.get(self.relation_name)
         Target = self.get_target()
-
-        if self.origin in Relation._fields:
-            origin_field = Relation._fields[self.origin]
-        else:
-            origin_field = Relation._inherit_fields[self.origin][2]
+        origin_field = Relation._fields[self.origin]
 
         def search_clause(ids):
             if origin_field._type == 'reference':
@@ -137,11 +130,15 @@ class Many2Many(Field):
 
         for act in values:
             if act[0] == 'create':
+                to_create = []
                 for record_id in ids:
-                    Relation.create({
-                            self.origin: field_value(record_id),
-                            self.target: Target.create(act[1]).id,
-                            })
+                    for new in Target.create(act[1]):
+                        to_create.append({
+                                self.origin: field_value(record_id),
+                                self.target: new.id,
+                                })
+                if to_create:
+                    Relation.create(to_create)
             elif act[0] == 'write':
                 Target.write(Target.browse(act[1]), act[2])
             elif act[0] == 'delete':
@@ -182,12 +179,15 @@ class Many2Many(Field):
                             ])
                     for relation in relations:
                         existing_ids.append(getattr(relation, self.target).id)
+                to_create = []
                 for new_id in (x for x in target_ids if x not in existing_ids):
                     for record_id in ids:
-                        Relation.create({
+                        to_create.append({
                                 self.origin: field_value(record_id),
                                 self.target: new_id,
                                 })
+                if to_create:
+                    Relation.create(to_create)
             elif act[0] == 'unlink_all':
                 targets = Relation.search([
                         search_clause(ids),
@@ -205,12 +205,15 @@ class Many2Many(Field):
                         ])
                 Relation.delete(targets2)
 
+                to_create = []
                 for new_id in target_ids:
                     for record_id in ids:
-                        Relation.create({
+                        to_create.append({
                                 self.origin: field_value(record_id),
                                 self.target: new_id,
                                 })
+                if to_create:
+                    Relation.create(to_create)
             else:
                 raise Exception('Bad arguments')
 
@@ -219,10 +222,7 @@ class Many2Many(Field):
         Relation = Pool().get(self.relation_name)
         if not self.target:
             return Relation
-        if self.target in Relation._fields:
-            return Relation._fields[self.target].get_target()
-        else:
-            return Relation._inherit_fields[self.target][2].get_target()
+        return Relation._fields[self.target].get_target()
 
     def __set__(self, inst, value):
         Target = self.get_target()
