@@ -79,14 +79,12 @@ class One2Many(Field):
         '''
         pool = Pool()
         Relation = pool.get(self.model_name)
-        if self.field in Relation._fields:
-            field = Relation._fields[self.field]
-        else:
-            field = Relation._inherit_fields[self.field][2]
+        field = Relation._fields[self.field]
         res = {}
         for i in ids:
             res[i] = []
-        ids2 = []
+
+        targets = []
         for i in range(0, len(ids), Transaction().cursor.IN_MAX):
             sub_ids = ids[i:i + Transaction().cursor.IN_MAX]
             if field._type == 'reference':
@@ -94,43 +92,19 @@ class One2Many(Field):
                 clause = [(self.field, 'in', references)]
             else:
                 clause = [(self.field, 'in', sub_ids)]
-            ids2.append(map(int, Relation.search(clause, order=self.order)))
+            targets.append(Relation.search(clause, order=self.order))
+        targets = list(chain(*targets))
 
-        cache = Transaction().cursor.get_cache(Transaction().context)
-        cache.setdefault(self.model_name, {})
-        ids3 = []
-        for i in chain(*ids2):
-            if i in cache[self.model_name] \
-                    and self.field in cache[self.model_name][i]:
-                if field._type == 'reference':
-                    _, id_ = cache[self.model_name][i][self.field].split(',')
-                    id_ = int(id_)
-                else:
-                    id_ = cache[self.model_name][i][self.field]
-                res[id_].append(i)
-            else:
-                ids3.append(i)
-
-        if ids3:
-            for i in Relation.read(ids3, [self.field]):
-                if field._type == 'reference':
-                    _, id_ = i[self.field].split(',')
-                    id_ = int(id_)
-                else:
-                    id_ = i[self.field]
-                res[id_].append(i['id'])
-
-        index_of_ids2 = dict((i, index)
-            for index, i in enumerate(chain(*ids2)))
-        for id_, val in res.iteritems():
-            res[id_] = tuple(sorted(val, key=lambda x: index_of_ids2[x]))
-        return res
+        for target in targets:
+            origin_id = getattr(target, self.field).id
+            res[origin_id].append(target.id)
+        return dict((key, tuple(value)) for key, value in res.iteritems())
 
     def set(self, ids, model, name, values):
         '''
         Set the values.
         values: A list of tuples:
-            (``create``, ``{<field name>: value}``),
+            (``create``, ``[{<field name>: value}, ...]``),
             (``write``, ``<ids>``, ``{<field name>: value}``),
             (``delete``, ``<ids>``),
             (``delete_all``),
@@ -142,10 +116,7 @@ class One2Many(Field):
         if not values:
             return
         Target = self.get_target()
-        if self.field in Target._fields:
-            field = Target._fields[self.field]
-        else:
-            field = Target._inherit_fields[self.field][2]
+        field = Target._fields[self.field]
 
         def search_clause(ids):
             if field._type == 'reference':
@@ -162,9 +133,15 @@ class One2Many(Field):
 
         for act in values:
             if act[0] == 'create':
+                to_create = []
                 for record_id in ids:
-                    act[1][self.field] = field_value(record_id)
-                    Target.create(act[1])
+                    value = field_value(record_id)
+                    for vals in act[1]:
+                        vals = vals.copy()
+                        vals[self.field] = value
+                        to_create.append(vals)
+                if to_create:
+                    Target.create(to_create)
             elif act[0] == 'write':
                 Target.write(Target.browse(act[1]), act[2])
             elif act[0] == 'delete':
