@@ -16,33 +16,11 @@ from trytond.rpc import RPC
 __all__ = ['Model']
 
 
-class ModelMeta(PoolMeta):
-
-    def __getattr__(self, name):
-        pool = Pool()
-        for model_name, _ in self._inherits.iteritems():
-            Model = pool.get(model_name)
-            if isinstance(getattr(Model, name, None),
-                    collections.Callable):
-                meth = getattr(Model, name)
-                if not hasattr(meth, 'im_self') or meth.im_self:
-                    # Return classmethod bounded to inherited class
-                    return meth
-                else:
-                    for cls in Model.__mro__:
-                        if name in cls.__dict__:
-                            # Return a method bounded to current class
-                            return cls.__dict__[name].__get__(None, self)
-        raise AttributeError("'%s' Model has no attribute '%s'"
-            % (self.__name__, name))
-
-
 class Model(WarningErrorMixin, URLMixin):
     """
     Define a model in Tryton.
     """
-    __metaclass__ = ModelMeta
-    _inherits = {}
+    __metaclass__ = PoolMeta
     _rec_name = 'name'
 
     id = fields.Integer('ID', readonly=True)
@@ -76,48 +54,21 @@ class Model(WarningErrorMixin, URLMixin):
             if isinstance(getattr(cls, attr), fields.Field):
                 cls._fields[attr] = getattr(cls, attr)
 
-        # Set _inherit_fields
-        cls._inherit_fields = {}
-        for model_name in cls._inherits:
-            Model = pool.get(model_name)
-            cls._inherit_fields.update(Model._inherit_fields)
-            for field_name in Model._fields.keys():
-                cls._inherit_fields[field_name] = (model_name,
-                    cls._inherits[model_name],
-                    Model._fields[field_name])
-            for field_name in Model._inherit_fields.keys():
-                cls._inherit_fields[field_name] = (model_name,
-                    cls._inherits[model_name],
-                    Model._inherit_fields[field_name][2])
-        # Update models that uses this one in _inherits
-        for _, Model in pool.iterobject():
-            if cls.__name__ in Model._inherits:
-                Model.__post_setup__()
-
         # Set _defaults
         cls._defaults = {}
         fields_names = cls._fields.keys()
-        fields_names += cls._inherit_fields.keys()
         for field_name in fields_names:
             default_method = getattr(cls, 'default_%s' % field_name, False)
-            if not default_method and field_name in cls._inherit_fields:
-                icls = pool.get(cls._inherit_fields[field_name][0])
-                default_method = getattr(icls, 'default_%s' % field_name,
-                    False)
             if isinstance(default_method, collections.Callable):
                 cls._defaults[field_name] = default_method
 
         for k in cls._defaults:
-            assert (k in cls._fields) or (k in cls._inherit_fields), \
+            assert k in cls._fields, \
                 'Default function defined in %s but field %s does not exist!' \
                 % (cls.__name__, k,)
 
         # Update __rpc__
-        for field_name in cls._fields.keys() + cls._inherit_fields.keys():
-            if field_name in cls._fields:
-                field = cls._fields[field_name]
-            else:
-                field = cls._inherit_fields[field_name][2]
+        for field_name, field in cls._fields.iteritems():
             if isinstance(field, (fields.Selection, fields.Reference)) \
                     and not isinstance(field.selection, (list, tuple)) \
                     and field.selection not in cls.__rpc__:
@@ -188,12 +139,12 @@ class Model(WarningErrorMixin, URLMixin):
         if cls.__doc__:
             name = cls.__name__ + ',name'
             src = cls._get_name()
-            cursor.execute('SELECT id FROM ir_translation ' \
-                    'WHERE lang = %s ' \
-                        'AND type = %s ' \
-                        'AND name = %s ' \
-                        'AND (res_id IS NULL OR res_id = %s)',
-                    ('en_US', 'model', name, 0))
+            cursor.execute('SELECT id FROM ir_translation '
+                'WHERE lang = %s '
+                    'AND type = %s '
+                    'AND name = %s '
+                    'AND (res_id IS NULL OR res_id = %s)',
+                ('en_US', 'model', name, 0))
             trans_id = None
             if cursor.rowcount == -1 or cursor.rowcount is None:
                 data = cursor.fetchone()
@@ -215,28 +166,27 @@ class Model(WarningErrorMixin, URLMixin):
                         (src, src_md5, trans_id))
 
         # Add field in ir_model_field and update translation
-        cursor.execute('SELECT f.id AS id, f.name AS name, ' \
-                    'f.field_description AS field_description, ' \
-                    'f.ttype AS ttype, f.relation AS relation, ' \
-                    'f.module as module, f.help AS help '\
-                'FROM ir_model_field AS f, ir_model AS m ' \
-                'WHERE f.model = m.id ' \
-                    'AND m.model = %s ',
-                        (cls.__name__,))
+        cursor.execute('SELECT f.id AS id, f.name AS name, '
+                'f.field_description AS field_description, '
+                'f.ttype AS ttype, f.relation AS relation, '
+                'f.module as module, f.help AS help '
+            'FROM ir_model_field AS f, ir_model AS m '
+            'WHERE f.model = m.id '
+                'AND m.model = %s ',
+            (cls.__name__,))
         model_fields = {}
         for field in cursor.dictfetchall():
             model_fields[field['name']] = field
 
         # Prefetch field translations
         if cls._fields:
-            cursor.execute('SELECT id, name, src, type FROM ir_translation ' \
-                    'WHERE lang = %s ' \
-                        'AND type IN (%s, %s, %s) ' \
-                        'AND name IN ' \
-                            '(' + ','.join(('%s',) * len(cls._fields)) + ')',
-                            ('en_US', 'field', 'help', 'selection') + \
-                                    tuple([cls.__name__ + ',' + x \
-                                        for x in cls._fields]))
+            cursor.execute('SELECT id, name, src, type FROM ir_translation '
+                'WHERE lang = %s '
+                    'AND type IN (%s, %s, %s) '
+                    'AND name IN '
+                        '(' + ','.join(('%s',) * len(cls._fields)) + ')',
+                ('en_US', 'field', 'help', 'selection')
+                + tuple([cls.__name__ + ',' + x for x in cls._fields]))
         trans_fields = {}
         trans_help = {}
         trans_selection = {}
@@ -257,24 +207,24 @@ class Model(WarningErrorMixin, URLMixin):
             elif hasattr(field, 'relation_name'):
                 relation = field.relation_name
             if field_name not in model_fields:
-                cursor.execute("INSERT INTO ir_model_field " \
-                        "(model, name, field_description, ttype, " \
-                            "relation, help, module) " \
-                        "VALUES (%s, %s, %s, %s, %s, %s, %s)",
-                        (model_id, field_name, field.string, field._type,
-                            relation, field.help, module_name))
+                cursor.execute("INSERT INTO ir_model_field "
+                    "(model, name, field_description, ttype, "
+                        "relation, help, module) "
+                    "VALUES (%s, %s, %s, %s, %s, %s, %s)",
+                    (model_id, field_name, field.string, field._type,
+                        relation, field.help, module_name))
             elif (model_fields[field_name]['field_description'] != field.string
                     or model_fields[field_name]['ttype'] != field._type
                     or model_fields[field_name]['relation'] != relation
                     or model_fields[field_name]['help'] != field.help):
-                cursor.execute('UPDATE ir_model_field ' \
-                        'SET field_description = %s, ' \
-                            'ttype = %s, ' \
-                            'relation = %s, ' \
-                            'help = %s ' \
-                        'WHERE id = %s ',
-                        (field.string, field._type, relation,
-                            field.help, model_fields[field_name]['id']))
+                cursor.execute('UPDATE ir_model_field '
+                    'SET field_description = %s, '
+                        'ttype = %s, '
+                        'relation = %s, '
+                        'help = %s '
+                    'WHERE id = %s ',
+                    (field.string, field._type, relation,
+                        field.help, model_fields[field_name]['id']))
             trans_name = cls.__name__ + ',' + field_name
             string_md5 = Translation.get_src_md5(field.string)
             if trans_name not in trans_fields:
@@ -302,14 +252,14 @@ class Model(WarningErrorMixin, URLMixin):
                     'SET src = %s, src_md5 = %s '
                     'WHERE id = %s ',
                     (field.help, help_md5, trans_help[trans_name]['id']))
-            if hasattr(field, 'selection') \
-                    and isinstance(field.selection, (tuple, list)) \
-                    and ((hasattr(field, 'translate_selection') \
-                        and field.translate_selection)
-                        or not hasattr(field, 'translate_selection')):
+            if (hasattr(field, 'selection')
+                    and isinstance(field.selection, (tuple, list))
+                    and ((hasattr(field, 'translate_selection')
+                            and field.translate_selection)
+                        or not hasattr(field, 'translate_selection'))):
                 for (_, val) in field.selection:
-                    if trans_name not in trans_selection \
-                            or val not in trans_selection[trans_name]:
+                    if (trans_name not in trans_selection
+                            or val not in trans_selection[trans_name]):
                         val_md5 = Translation.get_src_md5(val)
                         cursor.execute('INSERT INTO ir_translation '
                             '(name, lang, type, src, src_md5, value, module, '
@@ -323,16 +273,16 @@ class Model(WarningErrorMixin, URLMixin):
                     and field_name not in cls._fields:
                 #XXX This delete field even when it is defined later
                 # in the module
-                cursor.execute('DELETE FROM ir_model_field '\
-                                   'WHERE id = %s',
-                               (model_fields[field_name]['id'],))
+                cursor.execute('DELETE FROM ir_model_field '
+                    'WHERE id = %s',
+                    (model_fields[field_name]['id'],))
 
         # Add error messages in ir_translation
-        cursor.execute('SELECT id, src FROM ir_translation ' \
-                'WHERE lang = %s ' \
-                    'AND type = %s ' \
-                    'AND name = %s',
-                ('en_US', 'error', cls.__name__))
+        cursor.execute('SELECT id, src FROM ir_translation '
+            'WHERE lang = %s '
+                'AND type = %s '
+                'AND name = %s',
+            ('en_US', 'error', cls.__name__))
         trans_error = {}
         for trans in cursor.dictfetchall():
             trans_error[trans['src']] = trans
@@ -365,10 +315,7 @@ class Model(WarningErrorMixin, URLMixin):
         for field_name in fields_names:
             if field_name in cls._defaults:
                 value[field_name] = cls._defaults[field_name]()
-            if field_name in cls._fields:
-                field = cls._fields[field_name]
-            else:
-                field = cls._inherit_fields[field_name][2]
+            field = cls._fields[field_name]
             if (field._type == 'boolean'
                     and not field_name in value):
                 value[field_name] = False
@@ -398,8 +345,6 @@ class Model(WarningErrorMixin, URLMixin):
         pool = Pool()
         res = value.copy()
         val = {}
-        for i in cls._inherits.keys():
-            val.update(pool.get(i)._default_on_change(value))
         for field in value.keys():
             if field in cls._fields:
                 if cls._fields[field].on_change:
@@ -424,9 +369,6 @@ class Model(WarningErrorMixin, URLMixin):
         Translation = pool.get('ir.translation')
         FieldAccess = pool.get('ir.model.field.access')
 
-        for parent in cls._inherits:
-            res.update(pool.get(parent).fields_get(fields_names))
-
         #Add translation to cache
         language = Transaction().language
         trans_args = []
@@ -437,12 +379,12 @@ class Model(WarningErrorMixin, URLMixin):
             trans_args.append((cls.__name__ + ',' + field, 'help', language,
                 None))
             if hasattr(cls._fields[field], 'selection'):
-                if isinstance(cls._fields[field].selection, (tuple, list)) \
+                if (isinstance(cls._fields[field].selection, (tuple, list))
                         and ((hasattr(cls._fields[field],
-                            'translate_selection') \
-                            and cls._fields[field].translate_selection) \
+                                    'translate_selection')
+                                and cls._fields[field].translate_selection)
                             or not hasattr(cls._fields[field],
-                                'translate_selection')):
+                                'translate_selection'))):
                     sel = cls._fields[field].selection
                     for (key, val) in sel:
                         trans_args.append((cls.__name__ + ',' + field,
@@ -451,12 +393,7 @@ class Model(WarningErrorMixin, URLMixin):
 
         encoder = PYSONEncoder()
 
-        fwrite_accesses = FieldAccess.check(cls.__name__, fields_names or
-            cls._fields.keys(), 'write', access=True)
-        fcreate_accesses = FieldAccess.check(cls.__name__, fields_names or
-            cls._fields.keys(), 'create', access=True)
-        fdelete_accesses = FieldAccess.check(cls.__name__, fields_names or
-            cls._fields.keys(), 'delete', access=True)
+        accesses = FieldAccess.get_access([cls.__name__])[cls.__name__]
         for field in (x for x in cls._fields.keys()
                 if ((not fields_names) or x in fields_names)):
             res[field] = {
@@ -480,11 +417,12 @@ class Model(WarningErrorMixin, URLMixin):
                     'datetime_field',
                     'loading',
                     'filename',
+                    'selection_change_with',
                     ):
                 if getattr(cls._fields[field], arg, None) is not None:
                     res[field][arg] = copy.copy(getattr(cls._fields[field],
                         arg))
-            if not fwrite_accesses.get(field, True):
+            if not accesses.get(field, {}).get('write', True):
                 res[field]['readonly'] = True
                 if res[field].get('states') and \
                         'readonly' in res[field]['states']:
@@ -521,12 +459,12 @@ class Model(WarningErrorMixin, URLMixin):
             if hasattr(cls._fields[field], 'selection'):
                 if isinstance(cls._fields[field].selection, (tuple, list)):
                     sel = copy.copy(cls._fields[field].selection)
-                    if Transaction().context.get('language') and \
-                            ((hasattr(cls._fields[field],
-                                'translate_selection') \
-                                and cls._fields[field].translate_selection) \
+                    if (Transaction().context.get('language')
+                            and ((hasattr(cls._fields[field],
+                                        'translate_selection')
+                                    and cls._fields[field].translate_selection)
                                 or not hasattr(cls._fields[field],
-                                    'translate_selection')):
+                                    'translate_selection'))):
                         # translate each selection option
                         sel2 = []
                         for (key, val) in sel:
@@ -554,14 +492,26 @@ class Model(WarningErrorMixin, URLMixin):
                 res[field]['relation'] = relation
                 res[field]['domain'] = copy.copy(cls._fields[field].domain)
                 res[field]['context'] = copy.copy(cls._fields[field].context)
-                res[field]['create'] = fcreate_accesses.get(field, True)
-                res[field]['delete'] = fdelete_accesses.get(field, True)
+                res[field]['create'] = accesses.get(field, {}).get('create',
+                    True)
+                res[field]['delete'] = accesses.get(field, {}).get('delete',
+                    True)
             if res[field]['type'] == 'one2many' \
                     and hasattr(cls._fields[field], 'field'):
                 res[field]['relation_field'] = copy.copy(
                         cls._fields[field].field)
             if res[field]['type'] in ('datetime', 'time'):
                 res[field]['format'] = copy.copy(cls._fields[field].format)
+            if res[field]['type'] == 'selection':
+                res[field]['context'] = copy.copy(cls._fields[field].context)
+            if res[field]['type'] == 'dict':
+                res[field]['schema_model'] = cls._fields[field].schema_model
+                res[field]['domain'] = copy.copy(cls._fields[field].domain)
+                res[field]['context'] = copy.copy(cls._fields[field].context)
+                res[field]['create'] = accesses.get(field, {}).get('create',
+                    True)
+                res[field]['delete'] = accesses.get(field, {}).get('delete',
+                    True)
 
             # convert attributes into pyson
             for attr in ('states', 'domain', 'context', 'digits', 'size',
@@ -610,19 +560,6 @@ class Model(WarningErrorMixin, URLMixin):
     def __getattr__(self, name):
         if name == 'id':
             return self.__dict__['id']
-        if (name not in self._fields
-                and name not in self._inherit_fields):
-            # Search for method on inherits parents
-            pool = Pool()
-            for model_name, _ in self._inherits.iteritems():
-                iModel = pool.get(model_name)
-                if isinstance(getattr(iModel, name, None),
-                        collections.Callable):
-                    for cls in iModel.__mro__:
-                        if name in cls.__dict__:
-                            # Return a method bounded to current class
-                            return cls.__dict__[name].__get__(self,
-                                self.__class__)
         elif self._values and name in self._values:
             return self._values.get(name)
         raise AttributeError("'%s' Model has no attribute '%s': %s"
@@ -632,11 +569,6 @@ class Model(WarningErrorMixin, URLMixin):
         if name == 'id':
             self.__dict__['id'] = value
             return
-        if (name not in self._fields
-                and name in self._inherit_fields):
-            field = self._inherit_fields[name][2]
-            field.__set__(self, value)
-            return
         super(Model, self).__setattr__(name, value)
 
     def __getitem__(self, name):
@@ -645,8 +577,7 @@ class Model(WarningErrorMixin, URLMixin):
         return getattr(self, name)
 
     def __contains__(self, name):
-        return (name in self._fields
-            or name in self._inherit_fields)
+        return name in self._fields
 
     def __int__(self):
         return int(self.id)
@@ -691,10 +622,7 @@ class Model(WarningErrorMixin, URLMixin):
         values = {}
         if self._values:
             for fname, value in self._values.iteritems():
-                if fname in self._fields:
-                    field = self._fields[fname]
-                else:
-                    field = self._inherit_fields[fname][2]
+                field = self._fields[fname]
                 if isinstance(field, fields.Reference):
                     if value is not None:
                         value = str(value)
