@@ -18,13 +18,13 @@ class ModelSingleton(ModelStorage):
             return singletons[0]
 
     @classmethod
-    def create(cls, values):
+    def create(cls, vlist):
+        assert len(vlist) == 1
         singleton = cls.get_singleton()
-        if singleton:
-            cls.write([singleton], values)
-        else:
-            singleton = super(ModelSingleton, cls).create(values)
-        return singleton
+        if not singleton:
+            return super(ModelSingleton, cls).create(vlist)
+        cls.write([singleton], vlist[0])
+        return [singleton]
 
     @classmethod
     def read(cls, ids, fields_names=None):
@@ -32,11 +32,10 @@ class ModelSingleton(ModelStorage):
         if not singleton:
             res = cls.default_get(fields_names, with_rec_name=False)
             if not fields_names:
-                fields_names = (set(cls._fields.keys()
-                    + cls._inherit_fields.keys()))
+                fields_names = cls._fields.keys()
             for field_name in fields_names:
                 if field_name not in res:
-                    res[field_name] = False
+                    res[field_name] = None
             res['id'] = ids[0]
             return [res]
         res = super(ModelSingleton, cls).read([singleton.id],
@@ -48,7 +47,7 @@ class ModelSingleton(ModelStorage):
     def write(cls, records, values):
         singleton = cls.get_singleton()
         if not singleton:
-            return cls.create(values)
+            return cls.create([values])
         return super(ModelSingleton, cls).write([singleton], values)
 
     @classmethod
