@@ -8,13 +8,14 @@ import contextlib
 import traceback
 import sys
 import csv
+import warnings
 try:
     import cStringIO as StringIO
 except ImportError:
     import StringIO
 
 from decimal import Decimal
-from itertools import islice, ifilter, ifilterfalse, chain
+from itertools import islice, ifilter, chain, izip
 from functools import reduce
 
 from trytond.model import Model
@@ -49,7 +50,8 @@ class ModelStorage(Model):
         super(ModelStorage, cls).__setup__()
         if issubclass(cls, ModelView):
             cls.__rpc__.update({
-                    'create': RPC(readonly=False, result=int),
+                    'create': RPC(readonly=False,
+                        result=lambda r: map(int, r)),
                     'read': RPC(),
                     'write': RPC(readonly=False, instantiate=0),
                     'delete': RPC(readonly=False, instantiate=0),
@@ -74,23 +76,24 @@ class ModelStorage(Model):
         return datetime.datetime.today()
 
     @classmethod
-    def create(cls, values):
+    def create(cls, vlist):
         '''
-        Create record and return an instance.
+        Returns the list of created records.
         '''
         pool = Pool()
         ModelAccess = pool.get('ir.model.access')
         ModelFieldAccess = pool.get('ir.model.field.access')
 
         ModelAccess.check(cls.__name__, 'create')
-        ModelFieldAccess.check(cls.__name__,
-            [x for x in values if x in cls._fields], 'write')
+
+        all_fields = list(set(chain(*(v.iterkeys() for v in vlist))))
+        ModelFieldAccess.check(cls.__name__, all_fields, 'write')
 
         # Increase transaction counter
         Transaction().counter += 1
 
     @classmethod
-    def trigger_create(cls, record):
+    def trigger_create(cls, records):
         '''
         Trigger create actions
         '''
@@ -99,8 +102,12 @@ class ModelStorage(Model):
         if not triggers:
             return
         for trigger in triggers:
-            if Trigger.eval(trigger, record):
-                Trigger.trigger_action([record], trigger)
+            triggers = []
+            for record in records:
+                if Trigger.eval(trigger, record):
+                    triggers.append(record)
+            if triggers:
+                Trigger.trigger_action(triggers, trigger)
 
     @classmethod
     def read(cls, ids, fields_names=None):
@@ -243,11 +250,11 @@ class ModelStorage(Model):
                 ftype = field_defs[field_name]['type']
 
                 if field_name in (
-                    'create_date',
-                    'create_uid',
-                    'write_date',
-                    'write_uid',
-                    ):
+                        'create_date',
+                        'create_uid',
+                        'write_date',
+                        'write_uid',
+                        ):
                     del data[field_name]
 
                 if field_name in default:
@@ -259,13 +266,13 @@ class ModelStorage(Model):
                 elif ftype in ('many2one', 'one2one'):
                     try:
                         data[field_name] = data[field_name] and \
-                                data[field_name][0]
+                            data[field_name][0]
                     except Exception:
                         pass
                 elif ftype in ('one2many',):
                     if data[field_name]:
                         data_o2m[field_name] = data[field_name]
-                    data[field_name] = False
+                    data[field_name] = None
                 elif ftype == 'many2many':
                     if data[field_name]:
                         data[field_name] = [('set', data[field_name])]
@@ -280,21 +287,30 @@ class ModelStorage(Model):
         ids = map(int, records)
         datas = cls.read(ids, fields_names=fields_names)
         field_defs = cls.fields_get(fields_names=fields_names)
+        data_ids = []
+        to_create = []
+        o2m_to_create = []
         for data in datas:
-            data_id = data['id']
+            data_ids.append(data['id'])
             data, data_o2m = convert_data(field_defs, data)
-            new_record = cls.create(data)
-            if new_record:
-                new_ids[data_id] = new_record.id
-            else:
-                continue
+            to_create.append(data)
+            o2m_to_create.append(data_o2m)
+        new_records = cls.create(to_create)
+        for data_id, new_record, data_o2m in izip(data_ids, new_records,
+                o2m_to_create):
+            new_ids[data_id] = new_record.id
             for field_name in data_o2m:
                 Relation = pool.get(
                         field_defs[field_name]['relation'])
                 relation_field = field_defs[field_name]['relation_field']
                 if relation_field:
+                    field = Relation._fields[relation_field]
+                    if field._type == 'reference':
+                        value = str(new_record)
+                    else:
+                        value = new_record.id
                     Relation.copy(Relation.browse(data_o2m[field_name]),
-                        default={relation_field: new_ids[data_id]})
+                        default={relation_field: value})
 
         fields_translate = {}
         for field_name, field in field_defs.iteritems():
@@ -303,16 +319,15 @@ class ModelStorage(Model):
                 fields_translate[field_name] = field
 
         if fields_translate:
-            lang_ids = Lang.search([
+            langs = Lang.search([
                 ('translatable', '=', True),
                 ])
-            if lang_ids:
-                lang_ids += Lang.search([
-                    ('code', '=', CONFIG['language']),
-                    ])
-                langs = Lang.browse(lang_ids)
+            if langs:
                 for lang in langs:
-                    with Transaction().set_context(language=lang.code):
+                    # Prevent fuzzing translations when copying as the terms
+                    # should be the same.
+                    with Transaction().set_context(language=lang.code,
+                            fuzzy_translation=False):
                         datas = cls.read(ids,
                                 fields_names=fields_translate.keys() + ['id'])
                         for data in datas:
@@ -350,8 +365,7 @@ class ModelStorage(Model):
         records = cls.search(domain, offset=offset, limit=limit, order=order)
 
         if not fields_names:
-            fields_names = list(set(cls._fields.keys() \
-                    + cls._inherit_fields.keys()))
+            fields_names = cls._fields.keys()
         if 'id' not in fields_names:
             fields_names.append('id')
         return cls.read(map(int, records), fields_names)
@@ -362,10 +376,9 @@ class ModelStorage(Model):
         domain = reduce_domain(domain)
         # if the object has a field named 'active', filter out all inactive
         # records unless they were explicitely asked for
-        if not (('active' in cls._fields
-            or 'active' in cls._inherit_fields.keys())
-            and (active_test
-                and Transaction().context.get('active_test', True))):
+        if not ('active' in cls._fields
+                and active_test
+                and Transaction().context.get('active_test', True)):
             return domain
 
         def process(domain):
@@ -374,18 +387,19 @@ class ModelStorage(Model):
             while i < len(domain):
                 arg = domain[i]
                 #add test for xmlrpc that doesn't handle tuple
-                if isinstance(arg, tuple) or \
-                        (isinstance(arg, list) and len(arg) > 2 and \
-                        arg[1] in OPERATORS):
+                if (isinstance(arg, tuple)
+                        or (isinstance(arg, list)
+                            and len(arg) > 2
+                            and arg[1] in OPERATORS)):
                     if arg[0] == 'active':
                         active_found = True
                 elif isinstance(arg, list):
                     domain[i] = process(domain[i])
                 i += 1
             if not active_found:
-                if domain and ((isinstance(domain[0], basestring) \
-                        and domain[0] == 'AND') \
-                        or (not isinstance(domain[0], basestring))):
+                if (domain and ((isinstance(domain[0], basestring)
+                                and domain[0] == 'AND')
+                            or (not isinstance(domain[0], basestring)))):
                     domain.append(('active', '=', True))
                 else:
                     domain = ['AND', domain, ('active', '=', True)]
@@ -398,8 +412,7 @@ class ModelStorage(Model):
         It is used by the Function field rec_name.
         '''
         rec_name = self._rec_name
-        if (rec_name not in self._fields
-                and rec_name not in self._inherit_fields):
+        if rec_name not in self._fields:
             rec_name = 'id'
         return unicode(getattr(self, rec_name))
 
@@ -409,11 +422,21 @@ class ModelStorage(Model):
         Return a list of arguments for search on rec_name.
         '''
         rec_name = cls._rec_name
-        if (rec_name not in cls._fields
-                and rec_name not in cls._inherit_fields):
+        if rec_name not in cls._fields:
             return []
         return [(rec_name,) + clause[1:]]
 
+    @classmethod
+    def search_global(cls, text):
+        '''
+        Yield tuples (id, rec_name, icon) for text
+        '''
+        # TODO improve search clause
+        for record in cls.search([
+                    ('rec_name', 'ilike', '%%%s%%' % text),
+                    ]):
+            yield record.id, record.rec_name, None
+
     @classmethod
     def browse(cls, ids):
         '''
@@ -440,13 +463,7 @@ class ModelStorage(Model):
                     break
                 field_name = fields_tree[i]
                 eModel = pool.get(value.__name__)
-                if field_name in eModel._fields:
-                    field = eModel._fields[field_name]
-                elif field_name in eModel._inherit_fields:
-                    field = eModel._inherit_fields[field_name][2]
-                else:
-                    raise Exception('Field %s not available on object "%s"'
-                        % (field_name, eModel.__name__))
+                field = eModel._fields[field_name]
                 if field.states and 'invisible' in field.states:
                     pyson_invisible = PYSONEncoder().encode(
                             field.states['invisible'])
@@ -475,7 +492,7 @@ class ModelStorage(Model):
                             for child_fpos in xrange(len(fields_names)):
                                 if child_lines and child_lines[0][child_fpos]:
                                     data[child_fpos] = \
-                                            child_lines[0][child_fpos]
+                                        child_lines[0][child_fpos]
                             lines += child_lines[1:]
                             first = False
                         else:
@@ -549,7 +566,7 @@ class ModelStorage(Model):
                     warn('too_many_relations_found', value, relation)
                     res = None
                 else:
-                    res = res[0]
+                    res = res[0].id
                 return res
 
             def get_many2many(relation, value):
@@ -569,7 +586,7 @@ class ModelStorage(Model):
                     else:
                         res.extend(res2)
                 if len(res):
-                    res = [('set', res)]
+                    res = [('set', [x.id for x in res])]
                 return res
 
             def get_one2one(relation, value):
@@ -661,11 +678,11 @@ class ModelStorage(Model):
                         else:
                             res = bool(int(value))
                     elif field_type == 'integer':
-                        res = value and int(value) or None
+                        res = int(value) if value else None
                     elif field_type == 'float':
-                        res = value and float(value) or None
+                        res = float(value) if value else None
                     elif field_type == 'numeric':
-                        res = value and Decimal(value) or None
+                        res = Decimal(value) if value else None
                     elif field_type == 'date':
                         res = value and datetime.date(*time.strptime(value,
                             '%Y-%m-%d')[:3])
@@ -698,22 +715,22 @@ class ModelStorage(Model):
                 nbrmax = max(nbrmax, max2)
                 reduce(lambda x, y: x and y, newrow)
                 row[field] = (reduce(lambda x, y: x or y, newrow.values()) and
-                         [('create', newrow)]) or []
+                         [('create', [newrow])]) or []
                 i = max2
                 while (position + i) < len(data):
                     test = True
                     for j, field2 in enumerate(fields_names):
-                        if len(field2) <= (prefix_len + 1) \
-                               and data[position + i][j]:
+                        if (len(field2) <= (prefix_len + 1)
+                                and data[position + i][j]):
                             test = False
                             break
                     if not test:
                         break
                     (newrow, max2, _) = \
-                            process_lines(data, prefix + [field], newfd,
-                                    position + i)
+                        process_lines(data, prefix + [field], newfd,
+                            position + i)
                     if reduce(lambda x, y: x or y, newrow.values()):
-                        row[field].append(('create', newrow))
+                        row[field].append(('create', [newrow]))
                     i += max2
                     nbrmax = max(nbrmax, i)
             if prefix_len == 0:
@@ -739,13 +756,13 @@ class ModelStorage(Model):
             res = {}
             try:
                 (res, _, translate) = \
-                        process_lines(data, [], fields_def)
+                    process_lines(data, [], fields_def)
                 warning = warning_stream.getvalue()
                 if warning:
                     # XXX should raise Exception
                     Transaction().cursor.rollback()
                     return (-1, res, warning, '')
-                new_id = cls.create(res)
+                new_id, = cls.create([res])
                 for lang in translate:
                     with Transaction().set_context(language=lang):
                         cls.write(new_id, translate[lang])
@@ -777,18 +794,18 @@ class ModelStorage(Model):
         if Transaction().user == 0:
             return True
         with Transaction().set_user(0):
-            model_data_ids = ModelData.search([
+            models_data = ModelData.search([
                 ('model', '=', cls.__name__),
                 ('db_id', 'in', map(int, records)),
                 ])
-            if not model_data_ids:
+            if not models_data:
                 return True
-            if values == None:
+            if values is None:
                 return False
-            for line in ModelData.browse(model_data_ids):
-                if not line.values:
+            for model_data in models_data:
+                if not model_data.values:
                     continue
-                xml_values = safe_eval(line.values, {
+                xml_values = safe_eval(model_data.values, {
                     'Decimal': Decimal,
                     'datetime': datetime,
                     })
@@ -798,23 +815,17 @@ class ModelStorage(Model):
         return True
 
     @classmethod
-    def check_recursion(cls, records, parent='parent'):
+    def check_recursion(cls, records, parent='parent', rec_name='rec_name'):
         '''
         Function that checks if there is no recursion in the tree
         composed with parent as parent field name.
         '''
-        if parent in cls._fields:
-            parent_type = cls._fields[parent]._type
-        elif parent in cls._inherit_fields:
-            parent_type = cls._inherit_fields[parent][2]._type
-        else:
-            raise Exception('Field %s not available on object "%s"' % \
-                    (parent, cls.__name__))
+        parent_type = cls._fields[parent]._type
 
         if parent_type not in ('many2one', 'many2many'):
             raise Exception(
-                    'Unsupported field type "%s" for field "%s" on "%s"' % \
-                    (parent_type, parent, cls.__name__))
+                'Unsupported field type "%s" for field "%s" on "%s"'
+                % (parent_type, parent, cls.__name__))
 
         visited = set()
 
@@ -826,19 +837,25 @@ class ModelStorage(Model):
                     for walk in walker:
                         walked.add(walk.id)
                         if walk.id == record.id:
-                            return False
+                            cls.raise_user_error('recursion_error', {
+                                    'rec_name': getattr(record, rec_name),
+                                    'parent_rec_name': getattr(getattr(record,
+                                            parent), rec_name)
+                                    })
                     walker = list(chain(*(getattr(walk, parent)
                                 for walk in walker if walk.id not in visited)))
                 else:
                     walked.add(walker.id)
                     if walker.id == record.id:
-                        return False
+                        cls.raise_user_error('recursion_error', {
+                                'rec_name': getattr(record, rec_name),
+                                'parent_rec_name': getattr(getattr(record,
+                                        parent), rec_name)
+                                })
                     walker = (getattr(walker, parent) not in visited
                         and getattr(walker, parent))
             visited.update(walked)
 
-        return True
-
     @classmethod
     def _get_error_args(cls, field_name):
         pool = Pool()
@@ -855,6 +872,10 @@ class ModelStorage(Model):
                         model_field.model.name)
         return error_args
 
+    @classmethod
+    def validate(cls, records):
+        pass
+
     @classmethod
     def _validate(cls, records):
         pool = Pool()
@@ -863,8 +884,9 @@ class ModelStorage(Model):
             with Transaction().set_user(Transaction().context.get('user')):
                 return cls._validate(cls.browse(records))
 
-        for record in records:
-            record.pre_validate()
+        # Ensure that records are readable
+        with Transaction().set_user(0, set_context=True):
+            records = cls.browse(records)
 
         def call(name):
             method = getattr(cls, name)
@@ -873,6 +895,8 @@ class ModelStorage(Model):
             else:
                 return all(method(r) for r in records)
         for field in cls._constraints:
+            warnings.warn('_constraints is deprecated, override validate instead',
+                DeprecationWarning, stacklevel=2)
             if not call(field[0]):
                 cls.raise_user_error(field[1])
 
@@ -894,13 +918,16 @@ class ModelStorage(Model):
                     if isinstance(i, (list, tuple)):
                         if is_pyson(i):
                             return True
+            if isinstance(test, dict):
+                for key, value in test.items():
+                    if isinstance(value, PYSON):
+                        return True
+                    if isinstance(value, (list, tuple, dict)):
+                        if is_pyson(value):
+                            return True
             return False
 
         with Transaction().set_context(ctx_pref):
-            # Ensure that records are readable
-            with Transaction().set_user(0, set_context=True):
-                records = cls.browse(records)
-
             for field_name, field in cls._fields.iteritems():
                 if isinstance(field, fields.Function) and \
                         not field.setter:
@@ -908,7 +935,7 @@ class ModelStorage(Model):
                 # validate domain
                 if (field._type in
                         ('many2one', 'many2many', 'one2many', 'one2one')
-                    and field.domain):
+                        and field.domain):
                     if field._type in ('many2one', 'one2many'):
                         Relation = pool.get(field.model_name)
                     else:
@@ -967,7 +994,7 @@ class ModelStorage(Model):
 
                 def required_test(value, field_name):
                     if (isinstance(value, (type(None), type(False), list,
-                                    tuple, basestring))
+                                    tuple, basestring, dict))
                             and not value):
                         cls.raise_user_error('required_validation_record',
                             error_args=cls._get_error_args(field_name))
@@ -1048,6 +1075,32 @@ class ModelStorage(Model):
                             digits_test(getattr(record, field_name),
                                 field.digits, field_name)
 
+                # validate selection
+                if hasattr(field, 'selection') and field.selection:
+                    if isinstance(field.selection, (tuple, list)):
+                        test = set(dict(field.selection).keys())
+                    for record in records:
+                        value = getattr(record, field_name)
+                        if field._type == 'reference':
+                            if isinstance(value, ModelStorage):
+                                value = value.__class__.__name__
+                            elif value:
+                                value, _ = value.split(',')
+                        if not isinstance(field.selection, (tuple, list)):
+                            sel_func = getattr(cls, field.selection)
+                            if field.selection_change_with:
+                                test = sel_func(record)
+                            else:
+                                test = sel_func()
+                            test = set(dict(test))
+                        # None and '' are equivalent
+                        if '' in test or None in test:
+                            test.add('')
+                            test.add(None)
+                        if value not in test:
+                            cls.raise_user_error('selection_validation_record',
+                                error_args=cls._get_error_args(field_name))
+
                 def format_test(value, format, field_name):
                     if not value:
                         return
@@ -1078,13 +1131,18 @@ class ModelStorage(Model):
                             format_test(getattr(record, field_name),
                                 field.format, field_name)
 
+        for record in records:
+            record.pre_validate()
+
+        cls.validate(records)
+
+
     @classmethod
     def _clean_defaults(cls, defaults):
         pool = Pool()
         vals = {}
         for field in defaults.keys():
-            fld_def = (field in cls._fields) and cls._fields[field] \
-                    or cls._inherit_fields[field][2]
+            fld_def = cls._fields[field]
             if fld_def._type in ('many2one', 'one2one'):
                 if isinstance(defaults[field], (list, tuple)):
                     vals[field] = defaults[field][0]
@@ -1095,7 +1153,7 @@ class ModelStorage(Model):
                 vals[field] = []
                 for defaults2 in defaults[field]:
                     vals2 = obj._clean_defaults(defaults2)
-                    vals[field].append(('create', vals2))
+                    vals[field].append(('create', [vals2]))
             elif fld_def._type in ('many2many',):
                 vals[field] = [('set', defaults[field])]
             elif fld_def._type in ('boolean',):
@@ -1123,7 +1181,7 @@ class ModelStorage(Model):
             self._local_cache = _local_cache
         else:
             self._local_cache = LRUDict(RECORD_CACHE_SIZE)
-        self._local_counter = Transaction().counter
+        self._local_cache.counter = Transaction().counter
 
     @property
     def _cache(self):
@@ -1140,27 +1198,26 @@ class ModelStorage(Model):
                 raise
 
         counter = Transaction().counter
-        if self._local_counter != counter:
+        if self._local_cache.counter != counter:
             self._local_cache.clear()
-            self._local_counter = counter
+            self._local_cache.counter = counter
+
+        # fetch the definition of the field
+        try:
+            field = self._fields[name]
+        except KeyError:
+            raise AttributeError('"%s" has no attribute "%s"' % (self, name))
+
         try:
             return self._local_cache[self.id][name]
         except KeyError:
             pass
         try:
-            return self._cache[self.id][name]
+            if field._type not in ('many2one', 'reference'):
+                return self._cache[self.id][name]
         except KeyError:
             pass
 
-        # fetch the definition of the field
-        if name in self._fields:
-            field = self._fields[name]
-        elif name in self._inherit_fields:
-            field = self._inherit_fields[name][2]
-        else:
-            raise AttributeError("'%s' Model has no attribute '%s'"
-                % (self.__name__, name))
-
         # build the list of fields we will fetch
         ffields = {
             name: field,
@@ -1168,17 +1225,12 @@ class ModelStorage(Model):
         if field.loading == 'eager':
             FieldAccess = Pool().get('ir.model.field.access')
             fread_accesses = {}
-            for inherit_name in self._inherits:
-                Inherit = Pool().get(inherit_name)
-                fread_accesses.update(FieldAccess.check(inherit_name,
-                    Inherit._fields.keys(), 'read', access=True))
             fread_accesses.update(FieldAccess.check(self.__name__,
                 self._fields.keys(), 'read', access=True))
             to_remove = set(x for x, y in fread_accesses.iteritems()
                     if not y and x != name)
 
             threshold = BROWSE_FIELD_TRESHOLD
-            inherit_threshold = threshold - len(self._fields)
 
             def not_cached(item):
                 fname, field = item
@@ -1194,17 +1246,6 @@ class ModelStorage(Model):
                 fname, field = item
                 return fname in self._fields
 
-            if inherit_threshold > 0:
-                ifields = ((fname, field)
-                    for fname, (_, _, field) in
-                    self._inherit_fields.iteritems())
-                ifields = ifilterfalse(overrided,
-                    ifilter(to_load,
-                        ifilter(not_cached, ifields)))
-                ifields = islice(ifields, 0, inherit_threshold)
-                ffields.update(ifields)
-                threshold -= inherit_threshold
-
             ifields = ifilter(to_load,
                 ifilter(not_cached,
                     self._fields.iteritems()))
@@ -1214,26 +1255,16 @@ class ModelStorage(Model):
         # add datetime_field
         for field in ffields.values():
             if hasattr(field, 'datetime_field') and field.datetime_field:
-                if field.datetime_field in self._fields:
-                    datetime_field = self._fields[field.datetime_field]
-                else:
-                    datetime_field = self._inherit_fields[
-                            field.datetime_field][2]
+                datetime_field = self._fields[field.datetime_field]
                 ffields[field.datetime_field] = datetime_field
 
         def filter_(id_):
-            try:
-                if name in self._local_cache[id_]:
-                    return False
-                if name in self._cache[id_]:
-                    return False
-            except KeyError:
-                pass
-            return True
+            return (name not in self._cache.get(id_, {})
+                and name not in self._local_cache.get(id_, {}))
         index = self._ids.index(self.id)
         ids = chain(islice(self._ids, index, None),
             islice(self._ids, 0, max(index - 1, 0)))
-        ids = list(islice(ifilter(filter_, ids), self._cursor.IN_MAX))
+        ids = islice(ifilter(filter_, ids), self._cursor.IN_MAX)
 
         def instantiate(field, value, data):
             if field._type in ('many2one', 'one2one', 'reference'):
@@ -1254,14 +1285,15 @@ class ModelStorage(Model):
                     Model = field.get_target()
             except KeyError:
                 return value
+            ctx = {}
+            datetime_ = None
             if getattr(field, 'datetime_field', None):
-                _datetime = data.get(field.datetime_field)
-            else:
-                _datetime = None
-            with Transaction().set_context(_datetime=_datetime):
-                local_cache = model2cache.setdefault(Model,
+                datetime_ = data.get(field.datetime_field)
+                ctx = {'_datetime': datetime_}
+            with Transaction().set_context(**ctx):
+                local_cache = model2cache.setdefault((Model, datetime_),
                     LRUDict(RECORD_CACHE_SIZE))
-                ids = model2ids.setdefault(Model, [])
+                ids = model2ids.setdefault((Model, datetime_), [])
                 if field._type in ('many2one', 'one2one', 'reference'):
                     ids.append(value)
                     return Model(value, _ids=ids, _local_cache=local_cache)
@@ -1276,25 +1308,40 @@ class ModelStorage(Model):
         with contextlib.nested(Transaction().set_cursor(self._cursor),
                 Transaction().set_user(self._user),
                 Transaction().set_context(self._context)):
+            if self.id in self._cache and name in self._cache[self.id]:
+                # Use values from cache
+                ids = islice(chain(islice(self._ids, index, None),
+                        islice(self._ids, 0, max(index - 1, 0))),
+                    self._cursor.IN_MAX)
+                ffields = {name: ffields[name]}
+                read_data = [{'id': i, name: self._cache[i][name]}
+                    for i in ids
+                    if i in self._cache and name in self._cache[i]]
+            else:
+                read_data = self.read(list(ids), ffields.keys())
             # create browse records for 'remote' models
-            for data in self.read(ids, ffields.keys()):
+            for data in read_data:
                 for fname, field in ffields.iteritems():
+                    fvalue = data[fname]
                     if field._type in ('many2one', 'one2one', 'one2many',
                             'many2many', 'reference'):
-                        data[fname] = instantiate(field, data[fname], data)
-                    elif not isinstance(field, fields.Function):
-                        continue
+                        fvalue = instantiate(field, data[fname], data)
                     if data['id'] == self.id and fname == name:
-                        value = data[fname]
+                        value = fvalue
+                    if (field._type not in ('many2one', 'one2one', 'one2many',
+                                'many2many', 'reference')
+                            and not isinstance(field, fields.Function)):
+                        continue
                     if data['id'] not in self._local_cache:
                         self._local_cache[data['id']] = {}
-                    self._local_cache[data['id']][fname] = data[fname]
-                    del data[fname]
+                    self._local_cache[data['id']][fname] = fvalue
+                    if (field._type not in ('many2one', 'reference')
+                            or getattr(field, 'datetime_field', None)
+                            or isinstance(field, fields.Function)):
+                        del data[fname]
                 if data['id'] not in self._cache:
                     self._cache[data['id']] = {}
                 self._cache[data['id']].update(data)
-                if data['id'] == self.id and name in data:
-                    value = data[name]
         return value
 
     @property
@@ -1303,10 +1350,7 @@ class ModelStorage(Model):
         if not self._values:
             return values
         for fname, value in self._values.iteritems():
-            if fname in self._fields:
-                field = self._fields[fname]
-            else:
-                field = self._inherit_fields[fname][2]
+            field = self._fields[fname]
             if field._type in ('many2one', 'one2one', 'reference'):
                 if value:
                     if value.id < 0 and field._type != 'reference':
@@ -1322,29 +1366,35 @@ class ModelStorage(Model):
                     ]
                 for target in targets:
                     if target.id < 0:
-                        value.append(('create', target._save_values))
-                    elif target._save_values:
-                        value.append(
-                            ('write', [target.id], target._save_values))
+                        value.append(('create', [target._save_values]))
                     else:
                         value[0][1].append(target.id)
+                        if target._save_values:
+                            value.append(
+                                ('write', [target.id], target._save_values))
             values[fname] = value
         return values
 
     def save(self):
-        if self._save_values or self.id < 0:
-            with contextlib.nested(Transaction().set_cursor(self._cursor),
-                    Transaction().set_user(self._user),
-                    Transaction().set_context(self._context)):
-                if self.id < 0:
-                    self._ids.remove(self.id)
-                    try:
-                        self.id = self.create(self._save_values).id
-                    finally:
-                        self._ids.append(self.id)
-                else:
-                    self.write([self], self._save_values)
+        save_values = self._save_values
+        values = self._values
         self._values = None
+        if save_values or self.id < 0:
+            try:
+                with contextlib.nested(Transaction().set_cursor(self._cursor),
+                        Transaction().set_user(self._user),
+                        Transaction().set_context(self._context)):
+                    if self.id < 0:
+                        self._ids.remove(self.id)
+                        try:
+                            self.id = self.create([save_values])[0].id
+                        finally:
+                            self._ids.append(self.id)
+                    else:
+                        self.write([self], save_values)
+            except:
+                self._values = values
+                raise
 
 
 class EvalEnvironment(dict):
@@ -1357,14 +1407,10 @@ class EvalEnvironment(dict):
     def __getitem__(self, item):
         if item.startswith('_parent_'):
             field = item[8:]
-            if field in self._model._fields:
-                model_name = self._model._fields[field].model_name
-            else:
-                model_name = self._model._inherit_fields[field][2].model_name
+            model_name = self._model._fields[field].model_name
             ParentModel = Pool().get(model_name)
             return EvalEnvironment(getattr(self._record, field), ParentModel)
-        if (item in self._model._fields
-                or item in self._model._inherit_fields):
+        if item in self._model._fields:
             value = getattr(self._record, item)
             if isinstance(value, Model):
                 return value.id
