@@ -4,11 +4,7 @@
 import copy
 import string
 import random
-try:
-    import hashlib
-except ImportError:
-    hashlib = None
-    import sha
+import hashlib
 import time
 import datetime
 from itertools import groupby, ifilter
@@ -30,9 +26,10 @@ try:
     TIMEZONES = [(x, x) for x in pytz.common_timezones]
 except ImportError:
     TIMEZONES = []
+TIMEZONES += [(None, '')]
 
 __all__ = [
-    'User', 'UserAction', 'UserGroup', 'Warning_',
+    'User', 'LoginAttempt', 'UserAction', 'UserGroup', 'Warning_',
     'UserConfigStart', 'UserConfig',
     ]
 
@@ -42,7 +39,6 @@ class User(ModelSQL, ModelView):
     __name__ = "res.user"
     name = fields.Char('Name', required=True, select=True, translate=True)
     login = fields.Char('Login', required=True)
-    login_try = fields.Integer('Login Try', required=True)
     password = fields.Sha('Password')
     salt = fields.Char('Salt', size=8)
     signature = fields.Text('Signature')
@@ -60,7 +56,6 @@ class User(ModelSQL, ModelView):
     language = fields.Many2One('ir.lang', 'Language',
         domain=['OR',
             ('translatable', '=', True),
-            ('code', '=', CONFIG['language']),
             ])
     language_direction = fields.Function(fields.Char('Language Direction'),
             'get_language_direction')
@@ -104,10 +99,10 @@ class User(ModelSQL, ModelView):
             'groups',
         ]
         cls._error_messages.update({
-            'rm_root': 'You can not remove the root user\n' \
-                            'as it is used internally for resources\n' \
-                            'created by the system ' \
-                            '(updates, module installation, ...)',
+            'rm_root': ('You can not remove the root user\n'
+                    'as it is used internally for resources\n'
+                    'created by the system '
+                    '(updates, module installation, ...)'),
             'wrong_password': 'Wrong password!',
             })
 
@@ -134,9 +129,8 @@ class User(ModelSQL, ModelView):
         # Migration from 2.2
         table.not_null_action('menu', action='remove')
 
-    @staticmethod
-    def default_login_try():
-        return 0
+        # Migration from 2.6
+        table.drop_column('login_try', exception=True)
 
     @staticmethod
     def default_password():
@@ -215,9 +209,9 @@ class User(ModelSQL, ModelView):
         return vals
 
     @classmethod
-    def create(cls, vals):
-        vals = cls._convert_vals(vals)
-        res = super(User, cls).create(vals)
+    def create(cls, vlist):
+        vlist = [cls._convert_vals(vals) for vals in vlist]
+        res = super(User, cls).create(vlist)
         # Restart the cache for _get_login
         cls._get_login_cache.clear()
         return res
@@ -226,6 +220,12 @@ class User(ModelSQL, ModelView):
     def write(cls, users, vals):
         vals = cls._convert_vals(vals)
         super(User, cls).write(users, vals)
+        # Clean cursor cache as it could be filled by domain_get
+        for cache in Transaction().cursor.cache.itervalues():
+            if cls.__name__ in cache:
+                for user in users:
+                    if user.id in cache[cls.__name__]:
+                        cache[cls.__name__][user.id].clear()
         # Restart the cache for domain_get method
         pool = Pool()
         pool.get('ir.rule')._domain_get_cache.clear()
@@ -286,6 +286,7 @@ class User(ModelSQL, ModelView):
         ModelData = pool.get('ir.model.data')
         Action = pool.get('ir.action')
         ConfigItem = pool.get('ir.module.module.config_wizard.item')
+        Config = pool.get('ir.configuration')
 
         res = {}
         if context_only:
@@ -298,7 +299,7 @@ class User(ModelSQL, ModelView):
                     if user.language:
                         res['language'] = user.language.code
                     else:
-                        res['language'] = CONFIG['language']
+                        res['language'] = Config.get_language()
                 else:
                     res[field] = None
                     if getattr(user, field):
@@ -400,10 +401,7 @@ class User(ModelSQL, ModelView):
 
         if 'language' in res['fields']:
             selection = convert2selection(res['fields'], 'language')
-            langs = Lang.search(['OR',
-                    ('translatable', '=', True),
-                    ('code', '=', CONFIG['language']),
-                    ])
+            langs = Lang.search(cls.language.domain)
             lang_ids = [l.id for l in langs]
             with Transaction().set_context(translate_name=True):
                 for lang in Lang.browse(lang_ids):
@@ -438,15 +436,15 @@ class User(ModelSQL, ModelView):
 
     @classmethod
     def _get_login(cls, login):
-        result = cls._get_groups_cache.get(login)
+        result = cls._get_login_cache.get(login)
         if result:
             return result
         cursor = Transaction().cursor
-        cursor.execute('SELECT id, password, salt ' \
-                'FROM "' + cls._table + '" '
-                'WHERE login = %s AND active', (login,))
+        cursor.execute('SELECT id, password, salt '
+            'FROM "' + cls._table + '" '
+            'WHERE login = %s AND active', (login,))
         result = cursor.fetchone() or (None, None, None)
-        cls._get_groups_cache.set(login, result)
+        cls._get_login_cache.set(login, result)
         return result
 
     @classmethod
@@ -454,32 +452,50 @@ class User(ModelSQL, ModelView):
         '''
         Return user id if password matches
         '''
+        LoginAttempt = Pool().get('res.user.login.attempt')
         user_id, user_password, salt = cls._get_login(login)
         if not user_id:
             return 0
         password += salt or ''
         if isinstance(password, unicode):
             password = password.encode('utf-8')
-        if hashlib:
-            password_sha = hashlib.sha1(password).hexdigest()
-        else:
-            password_sha = sha.new(password).hexdigest()
-        cursor = Transaction().cursor
+        password_sha = hashlib.sha1(password).hexdigest()
         if password_sha == user_password:
-            cursor.execute('UPDATE "' + cls._table + '" '
-                'SET login_try = 0 '
-                'WHERE login = %s', (login,))
+            LoginAttempt.delete(user_id)
             return user_id
-        cursor.execute('UPDATE "' + cls._table + '" '
-            'SET login_try = login_try + 1 '
-            'WHERE login = %s', (login,))
-        cursor.execute('SELECT login_try FROM "' + cls._table + '" '
-            'WHERE login = %s', (login,))
-        login_try, = cursor.fetchone()
-        time.sleep(2 ** login_try)
+        LoginAttempt.add(user_id)
+        time.sleep(2 ** LoginAttempt.count(user_id))
         return 0
 
 
+class LoginAttempt(ModelSQL):
+    """Login Attempt
+
+    This class is separated from the res.user one in order to prevent locking
+    the res.user table when in a long running process.
+    """
+    __name__ = 'res.user.login.attempt'
+    user = fields.Many2One('res.user', 'User', required=True, select=True,
+        ondelete='CASCADE')
+
+    @classmethod
+    def add(cls, user_id):
+        cls.create([{'user': user_id}])
+
+    @classmethod
+    def delete(cls, user_id):
+        cursor = Transaction().cursor
+        cursor.execute('DELETE FROM "' + cls._table + '" WHERE "user" = %s',
+            (user_id,))
+
+    @classmethod
+    def count(cls, user_id):
+        cursor = Transaction().cursor
+        cursor.execute('SELECT count(1) FROM "'
+            + cls._table + '" WHERE "user" = %s', (user_id,))
+        return cursor.fetchone()[0]
+
+
 class UserAction(ModelSQL):
     'User - Action'
     __name__ = 'res.user-ir.action'
@@ -498,9 +514,9 @@ class UserAction(ModelSQL):
         return values
 
     @classmethod
-    def create(cls, values):
-        values = cls._convert_values(values)
-        return super(UserAction, cls).create(values)
+    def create(cls, vlist):
+        vlist = [cls._convert_values(values) for values in vlist]
+        return super(UserAction, cls).create(vlist)
 
     @classmethod
     def write(cls, records, values):
@@ -549,7 +565,7 @@ class Warning_(ModelSQL, ModelView):
             ])
         if not warnings:
             return True
-        cls.delete([x.id for x in warnings if not x.always])
+        cls.delete([x for x in warnings if not x.always])
         return False
 
 
@@ -575,5 +591,8 @@ class UserConfig(Wizard):
     add = StateTransition()
 
     def transition_add(self):
+        pool = Pool()
+        User = pool.get('res.user')
         self.user.save()
+        self.user = User()
         return 'user'
