@@ -32,6 +32,8 @@ __all__ = [
     'Many2ManySize', 'Many2ManySizeTarget', 'Many2ManySizeRelation',
     'Reference', 'ReferenceTarget', 'ReferenceRequired',
     'Property',
+    'Selection', 'SelectionRequired',
+    'Dict', 'DictDefault', 'DictRequired',
     ]
 
 
@@ -429,6 +431,7 @@ class One2ManyReferenceTarget(ModelSQL):
     __name__ = 'test.one2many_reference.target'
     name = fields.Char('Name', required=True)
     origin = fields.Reference('Origin', [
+            (None, ''),
             ('test.one2many_reference', 'One2Many Reference'),
             ])
 
@@ -520,6 +523,7 @@ class Many2ManyReferenceRelation(ModelSQL):
     'Many2Many Relation'
     __name__ = 'test.many2many_reference.relation'
     origin = fields.Reference('Origin', [
+            (None, ''),
             ('test.many2many_reference', 'Many2Many Reference'),
             ])
     target = fields.Many2One('test.many2many_reference.target',
@@ -551,6 +555,7 @@ class Reference(ModelSQL):
     __name__ = 'test.reference'
     name = fields.Char('Name', required=True)
     reference = fields.Reference('Reference', selection=[
+            (None, ''),
             ('test.reference.target', 'Target'),
             ])
 
@@ -566,6 +571,7 @@ class ReferenceRequired(ModelSQL):
     __name__ = 'test.reference_required'
     name = fields.Char('Name', required=True)
     reference = fields.Reference('Reference', selection=[
+            (None, ''),
             ('test.reference.target', 'Target'),
             ], required=True)
 
@@ -578,6 +584,58 @@ class Property(ModelSQL):
             'Test Many2One'))
     numeric = fields.Property(fields.Numeric('Test Numeric'))
     selection = fields.Property(fields.Selection([
+                (None, ''),
                 ('option_a', 'Option A'),
                 ('option_b', 'Option B')
             ], 'Test Selection'))
+
+
+class Selection(ModelSQL):
+    'Selection'
+    __name__ = 'test.selection'
+    select = fields.Selection([
+            ('', ''), ('arabic', 'Arabic'), ('hexa', 'Hexadecimal')],
+        'Selection')
+    dyn_select = fields.Selection('get_selection',
+        'Instance Dynamic Selection', selection_change_with=['select'])
+    dyn_select_static = fields.Selection('static_selection',
+        'Static Selection')
+
+    def get_selection(self):
+        if self.select == 'arabic':
+            return [('', '')] + [(str(i), str(i)) for i in range(1, 11)]
+        else:
+            return [('', '')] + [(hex(i), hex(i)) for i in range(1, 11)]
+
+    @staticmethod
+    def static_selection():
+        return [('', '')] + [(str(i), str(i)) for i in range(1, 11)]
+
+
+class SelectionRequired(ModelSQL):
+    'Selection Required'
+    __name__ = 'test.selection_required'
+    select = fields.Selection([('arabic', 'Arabic'), ('latin', 'Latin')],
+        'Selection', required=True)
+
+
+class Dict(ModelSQL):
+    'Dict'
+    __name__ = 'test.dict'
+    dico = fields.Dict(None, 'Test Dict')
+
+
+class DictDefault(ModelSQL):
+    'Dict Default'
+    __name__ = 'test.dict_default'
+    dico = fields.Dict(None, 'Test Dict')
+
+    @staticmethod
+    def default_dico():
+        return dict(a=1)
+
+
+class DictRequired(ModelSQL):
+    'Dict Required'
+    __name__ = 'test.dict_required'
+    dico = fields.Dict(None, 'Test Dict', required=True)
