@@ -28,7 +28,7 @@ class ModelAccessTestCase(unittest.TestCase):
                 context=CONTEXT) as transaction:
             model, = self.model.search([('model', '=', 'test.access')])
 
-            test = self.test_access.create({})
+            test, = self.test_access.create([{}])
 
             # Without model access
             self.test_access.read([test.id])
@@ -36,11 +36,11 @@ class ModelAccessTestCase(unittest.TestCase):
             # With model access
 
             # One access allowed for any group
-            model_access_wo_group = self.model_access.create({
-                    'model': model.id,
-                    'group': False,
-                    'perm_read': True,
-                    })
+            model_access_wo_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': None,
+                        'perm_read': True,
+                        }])
             self.test_access.read([test.id])
 
             # One access disallowed for any group
@@ -51,11 +51,11 @@ class ModelAccessTestCase(unittest.TestCase):
 
             # Two access rules with one group allowed
             group, = self.group.search([('users', '=', USER)])
-            model_access_w_group = self.model_access.create({
-                    'model': model.id,
-                    'group': group.id,
-                    'perm_read': True,
-                    })
+            model_access_w_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': group.id,
+                        'perm_read': True,
+                        }])
 
             self.test_access.read([test.id])
 
@@ -88,7 +88,7 @@ class ModelAccessTestCase(unittest.TestCase):
             self.test_access.read([test.id])
 
             # One access allowed for one other group
-            group = self.group.create({'name': 'Test'})
+            group, = self.group.create([{'name': 'Test'}])
             self.model_access.write([model_access_w_group], {
                     'group': group.id,
                     })
@@ -101,6 +101,7 @@ class ModelAccessTestCase(unittest.TestCase):
             self.test_access.read([test.id])
 
             transaction.cursor.rollback()
+            self.model_access._get_access_cache.clear()
 
     def test0020perm_write(self):
         '''
@@ -110,7 +111,7 @@ class ModelAccessTestCase(unittest.TestCase):
                 context=CONTEXT) as transaction:
             model, = self.model.search([('model', '=', 'test.access')])
 
-            test = self.test_access.create({})
+            test, = self.test_access.create([{}])
 
             # Without model access
             self.test_access.write([test], {})
@@ -118,11 +119,11 @@ class ModelAccessTestCase(unittest.TestCase):
             # With model access
 
             # One access allowed for any group
-            model_access_wo_group = self.model_access.create({
-                    'model': model.id,
-                    'group': False,
-                    'perm_write': True,
-                    })
+            model_access_wo_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': None,
+                        'perm_write': True,
+                        }])
             self.test_access.write([test], {})
 
             # One access disallowed for any group
@@ -133,11 +134,11 @@ class ModelAccessTestCase(unittest.TestCase):
 
             # Two access rules with one group allowed
             group, = self.group.search([('users', '=', USER)])
-            model_access_w_group = self.model_access.create({
-                    'model': model.id,
-                    'group': group.id,
-                    'perm_write': True,
-                    })
+            model_access_w_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': group.id,
+                        'perm_write': True,
+                        }])
             self.test_access.write([test], {})
 
             # Two access rules with both allowed
@@ -169,7 +170,7 @@ class ModelAccessTestCase(unittest.TestCase):
             self.test_access.write([test], {})
 
             # One access allowed for one other group
-            group = self.group.create({'name': 'Test'})
+            group, = self.group.create([{'name': 'Test'}])
             self.model_access.write([model_access_w_group], {
                     'group': group.id,
                     })
@@ -182,6 +183,7 @@ class ModelAccessTestCase(unittest.TestCase):
             self.test_access.write([test], {})
 
             transaction.cursor.rollback()
+            self.model_access._get_access_cache.clear()
 
     def test0030perm_create(self):
         '''
@@ -192,17 +194,17 @@ class ModelAccessTestCase(unittest.TestCase):
             model, = self.model.search([('model', '=', 'test.access')])
 
             # Without model access
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             # With model access
 
             # One access allowed for any group
-            model_access_wo_group = self.model_access.create({
-                    'model': model.id,
-                    'group': False,
-                    'perm_create': True,
-                    })
-            self.test_access.create({})
+            model_access_wo_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': None,
+                        'perm_create': True,
+                        }])
+            self.test_access.create([{}])
 
             # One access disallowed for any group
             self.model_access.write([model_access_wo_group], {
@@ -212,56 +214,57 @@ class ModelAccessTestCase(unittest.TestCase):
 
             # Two access rules with one group allowed
             group, = self.group.search([('users', '=', USER)])
-            model_access_w_group = self.model_access.create({
-                    'model': model.id,
-                    'group': group.id,
-                    'perm_create': True,
-                    })
+            model_access_w_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': group.id,
+                        'perm_create': True,
+                        }])
 
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             # Two access rules with both allowed
             self.model_access.write([model_access_wo_group], {
                     'perm_create': True,
                     })
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             # Two access rules with any group allowed
             self.model_access.write([model_access_w_group], {
                     'perm_create': False,
                     })
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             # Two access rules with both disallowed
             self.model_access.write([model_access_wo_group], {
                     'perm_create': False,
                     })
-            self.assertRaises(Exception, self.test_access.create, {})
+            self.assertRaises(Exception, self.test_access.create, [{}])
 
             # One access disallowed for one group
             self.model_access.delete([model_access_wo_group])
-            self.assertRaises(Exception, self.test_access.create, {})
+            self.assertRaises(Exception, self.test_access.create, [{}])
 
             # One access allowed for one group
             self.model_access.write([model_access_w_group], {
                     'perm_create': True,
                     })
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             # One access allowed for one other group
-            group = self.group.create({'name': 'Test'})
+            group, = self.group.create([{'name': 'Test'}])
             self.model_access.write([model_access_w_group], {
                     'group': group.id,
                     })
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             # One access disallowed for one other group
             self.model_access.write([model_access_w_group], {
                     'perm_create': False,
                     })
-            self.test_access.create({})
+            self.test_access.create([{}])
 
             transaction.cursor.rollback()
+            self.model_access._get_access_cache.clear()
 
     def test0040perm_delete(self):
         '''
@@ -271,7 +274,7 @@ class ModelAccessTestCase(unittest.TestCase):
                 context=CONTEXT) as transaction:
             model, = self.model.search([('model', '=', 'test.access')])
 
-            tests = [self.test_access.create({}) for x in range(11)]
+            tests = [self.test_access.create([{}])[0] for x in range(11)]
 
             # Without model access
             self.test_access.delete([tests.pop()])
@@ -279,11 +282,11 @@ class ModelAccessTestCase(unittest.TestCase):
             # With model access
 
             # One access allowed for any group
-            model_access_wo_group = self.model_access.create({
-                    'model': model.id,
-                    'group': False,
-                    'perm_delete': True,
-                    })
+            model_access_wo_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': None,
+                        'perm_delete': True,
+                        }])
             self.test_access.delete([tests.pop()])
 
             # One access disallowed for any group
@@ -295,11 +298,11 @@ class ModelAccessTestCase(unittest.TestCase):
 
             # Two access rules with one group allowed
             group = self.group.search([('users', '=', USER)])[0]
-            model_access_w_group = self.model_access.create({
-                    'model': model.id,
-                    'group': group.id,
-                    'perm_delete': True,
-                    })
+            model_access_w_group, = self.model_access.create([{
+                        'model': model.id,
+                        'group': group.id,
+                        'perm_delete': True,
+                        }])
 
             self.test_access.delete([tests.pop()])
 
@@ -334,7 +337,7 @@ class ModelAccessTestCase(unittest.TestCase):
             self.test_access.delete([tests.pop()])
 
             # One access allowed for one other group
-            group = self.group.create({'name': 'Test'})
+            group, = self.group.create([{'name': 'Test'}])
             self.model_access.write([model_access_w_group], {
                     'group': group.id,
                     })
@@ -347,6 +350,7 @@ class ModelAccessTestCase(unittest.TestCase):
             self.test_access.delete([tests.pop()])
 
             transaction.cursor.rollback()
+            self.model_access._get_access_cache.clear()
 
 
 class ModelFieldAccessTestCase(unittest.TestCase):
@@ -376,10 +380,10 @@ class ModelFieldAccessTestCase(unittest.TestCase):
                     ('name', '=', 'field2'),
                     ])
 
-            test = self.test_access.create({
-                    'field1': 'ham',
-                    'field2': 'spam',
-                    })
+            test, = self.test_access.create([{
+                        'field1': 'ham',
+                        'field2': 'spam',
+                        }])
 
             # Without field access
             self.test_access.read([test.id], ['field1'])
@@ -393,11 +397,11 @@ class ModelFieldAccessTestCase(unittest.TestCase):
             # With field access
 
             # One access allowed for any group
-            field_access_wo_group = self.field_access.create({
-                    'field': field1.id,
-                    'group': False,
-                    'perm_read': True,
-                    })
+            field_access_wo_group, = self.field_access.create([{
+                        'field': field1.id,
+                        'group': None,
+                        'perm_read': True,
+                        }])
             self.test_access.read([test.id], ['field1'])
             self.test_access.read([test.id], ['field2'])
             self.test_access.read([test.id])
@@ -422,11 +426,11 @@ class ModelFieldAccessTestCase(unittest.TestCase):
 
             # Two access rules with one group allowed
             group = self.group.search([('users', '=', USER)])[0]
-            field_access_w_group = self.field_access.create({
-                    'field': field1.id,
-                    'group': group.id,
-                    'perm_read': True,
-                    })
+            field_access_w_group, = self.field_access.create([{
+                        'field': field1.id,
+                        'group': group.id,
+                        'perm_read': True,
+                        }])
 
             self.test_access.read([test.id], ['field1'])
             self.test_access.read([test.id], ['field2'])
@@ -497,7 +501,7 @@ class ModelFieldAccessTestCase(unittest.TestCase):
             test = self.test_access(test.id)
 
             # One access allowed for one other group
-            group = self.group.create({'name': 'Test'})
+            group, = self.group.create([{'name': 'Test'}])
             self.field_access.write([field_access_w_group], {
                     'group': group.id,
                     })
@@ -524,16 +528,16 @@ class ModelFieldAccessTestCase(unittest.TestCase):
             # Two access rules on both fields allowed
             self.field_access.delete([field_access_w_group])
 
-            field_access1 = self.field_access.create({
-                    'field': field1.id,
-                    'group': False,
-                    'perm_read': True,
-                    })
-            field_access2 = self.field_access.create({
-                    'field': field2.id,
-                    'group': False,
-                    'perm_read': True,
-                    })
+            field_access1, = self.field_access.create([{
+                        'field': field1.id,
+                        'group': None,
+                        'perm_read': True,
+                        }])
+            field_access2, = self.field_access.create([{
+                        'field': field2.id,
+                        'group': None,
+                        'perm_read': True,
+                        }])
 
             self.test_access.read([test.id], ['field1'])
             self.test_access.read([test.id], ['field2'])
@@ -571,6 +575,7 @@ class ModelFieldAccessTestCase(unittest.TestCase):
             test = self.test_access(test.id)
 
             transaction.cursor.rollback()
+            self.field_access._get_access_cache.clear()
 
     def test0010perm_write(self):
         '''
@@ -587,10 +592,10 @@ class ModelFieldAccessTestCase(unittest.TestCase):
                     ('name', '=', 'field2'),
                     ])
 
-            test = self.test_access.create({
-                    'field1': 'ham',
-                    'field2': 'spam',
-                    })
+            test, = self.test_access.create([{
+                        'field1': 'ham',
+                        'field2': 'spam',
+                        }])
 
             # Without field access
             self.test_access.write([test], {})
@@ -600,11 +605,11 @@ class ModelFieldAccessTestCase(unittest.TestCase):
             # With field access
 
             # One access allowed for any group
-            field_access_wo_group = self.field_access.create({
-                    'field': field1.id,
-                    'group': False,
-                    'perm_write': True,
-                    })
+            field_access_wo_group, = self.field_access.create([{
+                        'field': field1.id,
+                        'group': None,
+                        'perm_write': True,
+                        }])
             self.test_access.write([test], {})
             self.test_access.write([test], {'field1': 'ham'})
             self.test_access.write([test], {'field2': 'spam'})
@@ -629,11 +634,11 @@ class ModelFieldAccessTestCase(unittest.TestCase):
 
             # Two access rules with one group allowed
             group = self.group.search([('users', '=', USER)])[0]
-            field_access_w_group = self.field_access.create({
-                    'field': field1.id,
-                    'group': group.id,
-                    'perm_write': True,
-                    })
+            field_access_w_group, = self.field_access.create([{
+                        'field': field1.id,
+                        'group': group.id,
+                        'perm_write': True,
+                        }])
 
             self.test_access.write([test], {})
             self.test_access.write([test], {'field1': 'ham'})
@@ -704,7 +709,7 @@ class ModelFieldAccessTestCase(unittest.TestCase):
                     })
 
             # One access allowed for one other group
-            group = self.group.create({'name': 'Test'})
+            group, = self.group.create([{'name': 'Test'}])
             self.field_access.write([field_access_w_group], {
                     'group': group.id,
                     })
@@ -731,16 +736,16 @@ class ModelFieldAccessTestCase(unittest.TestCase):
             # Two access rules on both fields allowed
             self.field_access.delete([field_access_w_group])
 
-            field_access1 = self.field_access.create({
-                    'field': field1.id,
-                    'group': False,
-                    'perm_write': True,
-                    })
-            field_access2 = self.field_access.create({
-                    'field': field2.id,
-                    'group': False,
-                    'perm_write': True,
-                    })
+            field_access1, = self.field_access.create([{
+                        'field': field1.id,
+                        'group': None,
+                        'perm_write': True,
+                        }])
+            field_access2, = self.field_access.create([{
+                        'field': field2.id,
+                        'group': None,
+                        'perm_write': True,
+                        }])
 
             self.test_access.write([test], {})
             self.test_access.write([test], {'field1': 'ham'})
@@ -778,6 +783,7 @@ class ModelFieldAccessTestCase(unittest.TestCase):
                     })
 
             transaction.cursor.rollback()
+            self.field_access._get_access_cache.clear()
 
 
 def suite():
