@@ -35,15 +35,15 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'boolean': True,
-                    })
+            export1, = self.export_data.create([{
+                        'boolean': True,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['boolean']), [[True]])
 
-            export2 = self.export_data.create({
-                    'boolean': False,
-                    })
+            export2, = self.export_data.create([{
+                        'boolean': False,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['boolean']),
                 [[False]])
@@ -61,15 +61,15 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'integer': 2,
-                    })
+            export1, = self.export_data.create([{
+                        'integer': 2,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['integer']), [[2]])
 
-            export2 = self.export_data.create({
-                    'integer': 0,
-                    })
+            export2, = self.export_data.create([{
+                        'integer': 0,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['integer']), [[0]])
 
@@ -85,15 +85,15 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'float': 1.1,
-                    })
+            export1, = self.export_data.create([{
+                        'float': 1.1,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['float']), [[1.1]])
 
-            export2 = self.export_data.create({
-                    'float': 0,
-                    })
+            export2, = self.export_data.create([{
+                        'float': 0,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['float']), [[0]])
 
@@ -109,16 +109,16 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'numeric': Decimal('1.1'),
-                    })
+            export1, = self.export_data.create([{
+                        'numeric': Decimal('1.1'),
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['numeric']),
                 [[Decimal('1.1')]])
 
-            export2 = self.export_data.create({
-                    'numeric': Decimal('0'),
-                    })
+            export2, = self.export_data.create([{
+                        'numeric': Decimal('0'),
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['numeric']),
                 [[Decimal('0')]])
@@ -135,15 +135,15 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'char': 'test',
-                    })
+            export1, = self.export_data.create([{
+                        'char': 'test',
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['char']), [['test']])
 
-            export2 = self.export_data.create({
-                    'char': None,
-                    })
+            export2, = self.export_data.create([{
+                        'char': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['char']), [['']])
 
@@ -159,15 +159,15 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'text': 'test',
-                    })
+            export1, = self.export_data.create([{
+                        'text': 'test',
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['text']), [['test']])
 
-            export2 = self.export_data.create({
-                    'text': None,
-                    })
+            export2, = self.export_data.create([{
+                        'text': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['text']), [['']])
 
@@ -183,9 +183,9 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'sha': 'Test',
-                    })
+            export1, = self.export_data.create([{
+                        'sha': 'Test',
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['sha']),
                 [['640ab2bae07bedc4c163f679a746f7ab7fb5d1fa']])
@@ -198,15 +198,15 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                'date': datetime.date(2010, 1, 1),
-                })
+            export1, = self.export_data.create([{
+                        'date': datetime.date(2010, 1, 1),
+                        }])
             self.assert_(self.export_data.export_data([export1],
                 ['date']) == [[datetime.date(2010, 1, 1)]])
 
-            export2 = self.export_data.create({
-                    'date': None,
-                    })
+            export2, = self.export_data.create([{
+                        'date': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['date']), [['']])
 
@@ -222,16 +222,16 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'datetime': datetime.datetime(2010, 1, 1, 12, 0, 0),
-                    })
+            export1, = self.export_data.create([{
+                        'datetime': datetime.datetime(2010, 1, 1, 12, 0, 0),
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['datetime']),
                 [[datetime.datetime(2010, 1, 1, 12, 0, 0)]])
 
-            export2 = self.export_data.create({
-                    'datetime': None,
-                    })
+            export2, = self.export_data.create([{
+                        'datetime': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['datetime']),
                 [['']])
@@ -248,16 +248,16 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({
-                    'selection': 'select1',
-                    })
+            export1, = self.export_data.create([{
+                        'selection': 'select1',
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['selection']),
                 [['select1']])
 
-            export2 = self.export_data.create({
-                    'selection': None,
-                    })
+            export2, = self.export_data.create([{
+                        'selection': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['selection']), [['']])
 
@@ -274,19 +274,19 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            target = self.export_data_target.create({
-                    'name': 'Target Test',
-                    })
-            export1 = self.export_data.create({
-                    'many2one': target.id,
-                    })
+            target, = self.export_data_target.create([{
+                        'name': 'Target Test',
+                        }])
+            export1, = self.export_data.create([{
+                        'many2one': target.id,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['many2one/name']),
                 [['Target Test']])
 
-            export2 = self.export_data.create({
+            export2, = self.export_data.create([{
                     'many2one': None,
-                    })
+                    }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['many2one/name']),
                 [['']])
@@ -304,19 +304,19 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            target1 = self.export_data_target.create({
-                    'name': 'Target 1',
-                    })
-            export1 = self.export_data.create({
-                    'many2many': [('set', [target1])],
-                    })
+            target1, = self.export_data_target.create([{
+                        'name': 'Target 1',
+                        }])
+            export1, = self.export_data.create([{
+                        'many2many': [('set', [target1])],
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['many2many/name']),
                 [['Target 1']])
 
-            target2 = self.export_data_target.create({
-                    'name': 'Target 2',
-                    })
+            target2, = self.export_data_target.create([{
+                        'name': 'Target 2',
+                        }])
             self.export_data.write([export1], {
                     'many2many': [('set', [target1.id, target2.id])],
                     })
@@ -325,9 +325,9 @@ class ExportDataTestCase(unittest.TestCase):
                         'many2many/name']),
                 [[export1.id, 'Target 1'], ['', 'Target 2']])
 
-            export2 = self.export_data.create({
-                    'many2many': None,
-                    })
+            export2, = self.export_data.create([{
+                        'many2many': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['many2many/name']),
                 [['']])
@@ -345,25 +345,25 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            export1 = self.export_data.create({})
-            self.export_data_target.create({
-                    'name': 'Target 1',
-                    'one2many': export1.id,
-                    })
+            export1, = self.export_data.create([{}])
+            self.export_data_target.create([{
+                        'name': 'Target 1',
+                        'one2many': export1.id,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['one2many/name']),
                 [['Target 1']])
 
-            self.export_data_target.create({
-                    'name': 'Target 2',
-                    'one2many': export1.id,
-                    })
+            self.export_data_target.create([{
+                        'name': 'Target 2',
+                        'one2many': export1.id,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1],
                     ['id', 'one2many/name']),
                 [[export1.id, 'Target 1'], ['', 'Target 2']])
 
-            export2 = self.export_data.create({})
+            export2, = self.export_data.create([{}])
             self.assertEqual(
                 self.export_data.export_data([export2], ['one2many/name']),
                 [['']])
@@ -381,17 +381,17 @@ class ExportDataTestCase(unittest.TestCase):
         '''
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            target1 = self.export_data_target.create({})
-            export1 = self.export_data.create({
-                    'reference': str(target1),
-                    })
+            target1, = self.export_data_target.create([{}])
+            export1, = self.export_data.create([{
+                        'reference': str(target1),
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export1], ['reference']),
                 [[str(target1)]])
 
-            export2 = self.export_data.create({
-                    'reference': None,
-                    })
+            export2, = self.export_data.create([{
+                        'reference': None,
+                        }])
             self.assertEqual(
                 self.export_data.export_data([export2], ['reference']), [['']])
 
