@@ -52,16 +52,19 @@ class TriggerTestCase(unittest.TestCase):
             model, = self.model.search([
                     ('model', '=', 'test.triggered'),
                     ])
+            action_model, = self.model.search([
+                    ('model', '=', 'test.trigger_action'),
+                    ])
 
             values = {
                 'name': 'Test',
                 'model': model.id,
                 'on_time': True,
                 'condition': 'True',
-                'action_model': model.id,
+                'action_model': action_model.id,
                 'action_function': 'test',
                 }
-            self.assert_(self.trigger.create(values))
+            self.assert_(self.trigger.create([values]))
 
             # on_exclusive
             for i in range(1, 4):
@@ -71,13 +74,13 @@ class TriggerTestCase(unittest.TestCase):
                     for mode in combination:
                         combination_values['on_%s' % mode] = True
                     self.assertRaises(Exception, self.trigger.create,
-                        combination_values)
+                        [combination_values])
 
             # check_condition
             condition_values = values.copy()
             condition_values['condition'] = '='
             self.assertRaises(Exception, self.trigger.create,
-                condition_values)
+                [condition_values])
 
             # Restart the cache on the get_triggers method of ir.trigger
             self.trigger._get_triggers_cache.clear()
@@ -92,19 +95,22 @@ class TriggerTestCase(unittest.TestCase):
             model, = self.model.search([
                     ('model', '=', 'test.triggered'),
                     ])
+            action_model, = self.model.search([
+                    ('model', '=', 'test.trigger_action'),
+                    ])
 
-            trigger = self.trigger.create({
-                    'name': 'Test',
-                    'model': model.id,
-                    'on_create': True,
-                    'condition': 'True',
-                    'action_model': model.id,
-                    'action_function': 'trigger',
-                    })
+            trigger, = self.trigger.create([{
+                        'name': 'Test',
+                        'model': model.id,
+                        'on_create': True,
+                        'condition': 'True',
+                        'action_model': action_model.id,
+                        'action_function': 'trigger',
+                        }])
 
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
 
             self.assertEqual(TRIGGER_LOGS, [([triggered], trigger)])
             TRIGGER_LOGS.pop()
@@ -115,16 +121,16 @@ class TriggerTestCase(unittest.TestCase):
                     })
 
             # Matching condition
-            triggered = self.triggered.create({
-                    'name': 'Bar',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Bar',
+                        }])
             self.assertEqual(TRIGGER_LOGS, [([triggered], trigger)])
             TRIGGER_LOGS.pop()
 
             # Non matching condition
-            triggered = self.triggered.create({
-                    'name': 'Foo',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Foo',
+                        }])
             self.assertEqual(TRIGGER_LOGS, [])
 
             # With limit number
@@ -132,9 +138,9 @@ class TriggerTestCase(unittest.TestCase):
                     'condition': 'True',
                     'limit_number': 1,
                     })
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
             self.assertEqual(TRIGGER_LOGS, [([triggered], trigger)])
             TRIGGER_LOGS.pop()
 
@@ -143,9 +149,9 @@ class TriggerTestCase(unittest.TestCase):
                     'limit_number': 0,
                     'minimum_delay': 1,
                     })
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
             self.assertEqual(TRIGGER_LOGS, [([triggered], trigger)])
             TRIGGER_LOGS.pop()
 
@@ -162,19 +168,22 @@ class TriggerTestCase(unittest.TestCase):
             model, = self.model.search([
                     ('model', '=', 'test.triggered'),
                     ])
+            action_model, = self.model.search([
+                    ('model', '=', 'test.trigger_action'),
+                    ])
 
-            trigger = self.trigger.create({
-                    'name': 'Test',
-                    'model': model.id,
-                    'on_write': True,
-                    'condition': 'True',
-                    'action_model': model.id,
-                    'action_function': 'trigger',
-                    })
+            trigger, = self.trigger.create([{
+                        'name': 'Test',
+                        'model': model.id,
+                        'on_write': True,
+                        'condition': 'True',
+                        'action_model': action_model.id,
+                        'action_function': 'trigger',
+                        }])
 
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
 
             self.triggered.write([triggered], {
                     'name': 'Foo',
@@ -210,9 +219,9 @@ class TriggerTestCase(unittest.TestCase):
                     'condition': 'self.name == "Bar"',
                     'limit_number': 1,
                     })
-            triggered = self.triggered.create({
-                    'name': 'Foo',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Foo',
+                        }])
             self.triggered.write([triggered], {
                     'name': 'Bar',
                     })
@@ -230,9 +239,9 @@ class TriggerTestCase(unittest.TestCase):
                     'limit_number': 0,
                     'minimum_delay': MAXINT,
                     })
-            triggered = self.triggered.create({
-                    'name': 'Foo',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Foo',
+                        }])
             for name in ('Bar', 'Foo', 'Bar'):
                 self.triggered.write([triggered], {
                         'name': name,
@@ -243,9 +252,9 @@ class TriggerTestCase(unittest.TestCase):
             self.trigger.write([trigger], {
                     'minimum_delay': 0.02,
                     })
-            triggered = self.triggered.create({
-                    'name': 'Foo',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Foo',
+                        }])
             for name in ('Bar', 'Foo'):
                 self.triggered.write([triggered], {
                         'name': name,
@@ -272,19 +281,22 @@ class TriggerTestCase(unittest.TestCase):
             model, = self.model.search([
                     ('model', '=', 'test.triggered'),
                     ])
+            action_model, = self.model.search([
+                    ('model', '=', 'test.trigger_action'),
+                    ])
 
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
 
-            trigger = self.trigger.create({
-                    'name': 'Test',
-                    'model': model.id,
-                    'on_delete': True,
-                    'condition': 'True',
-                    'action_model': model.id,
-                    'action_function': 'trigger',
-                    })
+            trigger, = self.trigger.create([{
+                        'name': 'Test',
+                        'model': model.id,
+                        'on_delete': True,
+                        'condition': 'True',
+                        'action_model': action_model.id,
+                        'action_function': 'trigger',
+                        }])
 
             self.triggered.delete([triggered])
             self.assertEqual(TRIGGER_LOGS, [([triggered], trigger)])
@@ -296,9 +308,9 @@ class TriggerTestCase(unittest.TestCase):
                     'condition': 'self.name == "Bar"',
                     })
 
-            triggered = self.triggered.create({
-                    'name': 'Bar',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Bar',
+                        }])
 
             # Matching condition
             self.triggered.delete([triggered])
@@ -306,18 +318,18 @@ class TriggerTestCase(unittest.TestCase):
             TRIGGER_LOGS.pop()
             Transaction().delete = {}
 
-            triggered = self.triggered.create({
-                    'name': 'Foo',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Foo',
+                        }])
 
             # Non matching condition
             self.triggered.delete([triggered])
             self.assertEqual(TRIGGER_LOGS, [])
             Transaction().delete = {}
 
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
 
             # With limit number
             self.trigger.write([trigger], {
@@ -333,9 +345,9 @@ class TriggerTestCase(unittest.TestCase):
                         ('trigger', '=', trigger.id),
                         ]))
 
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
 
             # With minimum delay
             self.trigger.write([trigger], {
@@ -360,19 +372,22 @@ class TriggerTestCase(unittest.TestCase):
             model, = self.model.search([
                     ('model', '=', 'test.triggered'),
                     ])
+            action_model, = self.model.search([
+                    ('model', '=', 'test.trigger_action'),
+                    ])
 
-            trigger = self.trigger.create({
-                    'name': 'Test',
-                    'model': model.id,
-                    'on_time': True,
-                    'condition': 'True',
-                    'action_model': model.id,
-                    'action_function': 'trigger',
-                    })
+            trigger, = self.trigger.create([{
+                        'name': 'Test',
+                        'model': model.id,
+                        'on_time': True,
+                        'condition': 'True',
+                        'action_model': action_model.id,
+                        'action_function': 'trigger',
+                        }])
 
-            triggered = self.triggered.create({
-                    'name': 'Test',
-                    })
+            triggered, = self.triggered.create([{
+                        'name': 'Test',
+                        }])
             self.trigger.trigger_time()
             self.assert_(TRIGGER_LOGS == [([triggered], trigger)])
             TRIGGER_LOGS.pop()
