@@ -202,6 +202,8 @@ def test_depends():
                 encoder.encode(field.domain)
                 if hasattr(field, 'digits'):
                     encoder.encode(field.digits)
+                if hasattr(field, 'add_remove'):
+                    encoder.encode(field.add_remove)
                 encoder.fields.discard(fname)
                 encoder.fields.discard('context')
                 encoder.fields.discard('_user')
@@ -209,6 +211,9 @@ def test_depends():
                 assert encoder.fields <= depends, (
                     'Missing depends %s in "%s"."%s"' % (
                         list(encoder.fields - depends), mname, fname))
+                assert depends <= set(model._fields), (
+                    'Unknown depends %s in "%s"."%s"' % (
+                        list(depends - set(model._fields)), mname, fname))
 
 
 def suite():
@@ -253,10 +258,12 @@ def all_suite():
     suite_.addTests(test_mixins.suite())
     import trytond.tests.test_wizard as test_wizard
     suite_.addTests(test_wizard.suite())
-    import trytond.tests.test_model_inherits as test_inherits
-    suite_.addTests(test_inherits.suite())
     import trytond.tests.test_modelsql as test_modelsql
     suite_.addTests(test_modelsql.suite())
+    import trytond.tests.test_cache as test_cache
+    suite_.addTests(test_cache.suite())
+    import trytond.tests.test_copy as test_copy
+    suite_.addTests(test_copy.suite())
     return suite_
 
 
@@ -266,7 +273,7 @@ def modules_suite():
     '''
     suite_ = all_suite()
     from trytond.modules import create_graph, get_module_list, \
-            MODULES_PATH, EGG_MODULES
+        MODULES_PATH, EGG_MODULES
     graph = create_graph(get_module_list())[0]
     for package in graph:
         module = package.name
