@@ -55,17 +55,11 @@ class Collection(ModelSQL, ModelView):
             ('name_parent_uniq', 'UNIQUE (name, parent)',
                 'The collection name must be unique inside a collection!'),
         ]
-        cls._constraints += [
-            ('check_recursion', 'recursive_collections'),
-            ('check_attachment', 'collection_file_name'),
-        ]
         cls._error_messages.update({
-            'recursive_collections': 'You can not create recursive ' \
-                    'collections!',
-            'collection_file_name': 'You can not create a collection\n' \
-                    'in a collection with the name of an ' \
-                    'existing file!',
-        })
+                'collection_file_name': ('You can not create a collection '
+                    'named "%(parent)s" in collection "%(child)s" because '
+                    'there is already a file with that name.'),
+                })
         cls.ext2mime = {
             '.png': 'image/png',
             '.odt': 'application/vnd.oasis.opendocument.text',
@@ -82,6 +76,12 @@ class Collection(ModelSQL, ModelView):
         else:
             return self.name
 
+    @classmethod
+    def validate(cls, collections):
+        super(Collection, cls).validate(collections)
+        cls.check_recursion(collections, rec_name='name')
+        cls.check_attachment(collections)
+
     @classmethod
     def check_attachment(cls, collections):
         pool = Pool()
@@ -94,8 +94,10 @@ class Collection(ModelSQL, ModelView):
                     ])
                 for attachment in attachments:
                     if attachment.name == collection.name:
-                        return False
-        return True
+                        cls.raise_user_error('collection_file_name', {
+                                'parent': collection.parent.rec_name,
+                                'child': collection.rec_name,
+                                })
 
     @classmethod
     def _uri2object(cls, uri, object_name=__name__, object_id=None,
@@ -132,7 +134,7 @@ class Collection(ModelSQL, ModelView):
                 for collection in collections:
                     if cache is not None:
                         cache['_parent2collection_ids'][object_id]\
-                                .setdefault(collection.name, [])
+                            .setdefault(collection.name, [])
                         cache['_parent2collection_ids'][object_id][
                             collection.name].append(collection.id)
                         cache.setdefault('_collection_name', {})
@@ -188,7 +190,7 @@ class Collection(ModelSQL, ModelView):
                             cache['_model&id&name2attachment_ids'].setdefault(
                                     key, {})
                             cache['_model&id&name2attachment_ids'][key]\
-                                    .setdefault(attachment.name, [])
+                                .setdefault(attachment.name, [])
                             cache['_model&id&name2attachment_ids'][key][
                                 attachment.name].append(attachment.id)
                         if attachment.name == name:
@@ -221,12 +223,12 @@ class Collection(ModelSQL, ModelView):
                     ('model', '=', object_name),
                     ])
                 for report in reports:
-                    report_name = report.name + '-' + str(report.id) \
-                            + '.' + report.extension
+                    report_name = (report.name + '-' + str(report.id)
+                        + '.' + report.extension)
                     if uri == report_name:
                         if cache is not None:
                             cache['_uri2object'][cache_uri] = \
-                                    ('ir.action.report', object_id)
+                                ('ir.action.report', object_id)
                         return 'ir.action.report', object_id
                 name = uri
                 attachment_ids = None
@@ -247,7 +249,7 @@ class Collection(ModelSQL, ModelView):
                     for attachment in attachments:
                         if cache is not None:
                             cache['_model&id2attachment_ids'][key]\
-                                    .setdefault(attachment.name, [])
+                                .setdefault(attachment.name, [])
                             cache['_model&id2attachment_ids'][key][
                                 attachment.name].append(attachment.id)
                         if attachment.name == name:
@@ -319,8 +321,8 @@ class Collection(ModelSQL, ModelView):
                 ('model', '=', object_name),
                 ])
             for report in reports:
-                report_name = report.name + '-' + str(report.id) \
-                        + '.' + report.extension
+                report_name = (report.name + '-' + str(report.id)
+                    + '.' + report.extension)
                 if '/' in report_name:
                     continue
                 res.append(report_name)
@@ -389,7 +391,7 @@ class Collection(ModelSQL, ModelView):
                 if cache is not None:
                     cache['ir.attachment'].setdefault(attachment.id, {})
                     cache['ir.attachment'][attachment.id]['contentlength'] = \
-                            size
+                        size
             return res
         return '0'
 
@@ -508,7 +510,7 @@ class Collection(ModelSQL, ModelView):
                     data = DAV_NotFound
                     try:
                         if attachment.data is not None:
-                            data = attachment.data
+                            data = str(attachment.data)
                     except Exception:
                         pass
                     if attachment.id == object_id:
@@ -539,7 +541,7 @@ class Collection(ModelSQL, ModelView):
         object_name, object_id = cls._uri2object(get_uriparentpath(uri),
                 cache=cache)
         if not object_name \
-                or object_name in ('ir.attachment') \
+                or object_name == 'ir.attachment' \
                 or not object_id:
             raise DAV_Forbidden
         pool = Pool()
@@ -548,11 +550,11 @@ class Collection(ModelSQL, ModelView):
         if not object_id2:
             name = get_urifilename(uri)
             try:
-                Attachment.create({
-                    'name': name,
-                    'data': data,
-                    'resource': '%s,%s' % (object_name, object_id),
-                    })
+                Attachment.create([{
+                            'name': name,
+                            'data': data,
+                            'resource': '%s,%s' % (object_name, object_id),
+                            }])
             except Exception:
                 raise DAV_Forbidden
         else:
@@ -576,30 +578,30 @@ class Collection(ModelSQL, ModelView):
             raise DAV_Forbidden
         name = get_urifilename(uri)
         try:
-            cls.create({
-                'name': name,
-                'parent': object_id,
-                })
+            cls.create([{
+                        'name': name,
+                        'parent': object_id,
+                        }])
         except Exception:
             raise DAV_Forbidden
         return 201
 
     @classmethod
     def rmcol(cls, uri, cache=None):
-        from pywebdav.errors import DAV_Forbidden
+        from pywebdav.lib.errors import DAV_Forbidden
         object_name, object_id = cls._uri2object(uri, cache=cache)
         if object_name != 'webdav.collection' \
                 or not object_id:
             raise DAV_Forbidden
         try:
-            cls.delete(object_id)
+            cls.delete([cls(object_id)])
         except Exception:
             raise DAV_Forbidden
         return 200
 
     @classmethod
     def rm(cls, uri, cache=None):
-        from pywebdav.errors import DAV_Forbidden
+        from pywebdav.lib.errors import DAV_Forbidden
         object_name, object_id = cls._uri2object(uri, cache=cache)
         if not object_name:
             raise DAV_Forbidden
@@ -609,7 +611,7 @@ class Collection(ModelSQL, ModelView):
         pool = Pool()
         Model = pool.get(object_name)
         try:
-            Model.delete(object_id)
+            Model.delete([Model(object_id)])
         except Exception:
             raise DAV_Forbidden
         return 200
@@ -697,14 +699,17 @@ class Attachment(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Attachment, cls).__setup__()
-        cls._constraints += [
-            ('check_collection', 'collection_attachment_name'),
-        ]
         cls._error_messages.update({
-            'collection_attachment_name': ('You can not create an attachment\n'
-                    'in a collection with the name\n'
-                    'of an existing child collection!'),
-        })
+                'collection_attachment_name': ('You can not create an '
+                    'attachment named "%(attachment)s in collection '
+                    '"%(collection)s" because there is already a collection '
+                    'with that name.')
+                })
+
+    @classmethod
+    def validate(cls, attachments):
+        super(Attachment, cls).validate(attachments)
+        cls.check_collection(attachments)
 
     @classmethod
     def check_collection(cls, attachments):
@@ -718,8 +723,11 @@ class Attachment(ModelSQL, ModelView):
                     collection = Collection(int(record_id))
                     for child in collection.childs:
                         if child.name == attachment.name:
-                            return False
-        return True
+                            cls.raise_user_error(
+                                'collection_attachment_name', {
+                                    'attachment': attachment.rec_name,
+                                    'collection': collection.rec_name,
+                                    })
 
     @classmethod
     def get_path(cls, attachments, name):
@@ -790,9 +798,14 @@ class Attachment(ModelSQL, ModelView):
 
         for action in value:
             if action[0] == 'create':
+                to_create = []
                 for attachment in attachments:
-                    action[1]['path'] = attachment.path
-                    Share.create(action[1])
+                    for values in action[1]:
+                        values = values.copy()
+                        values['path'] = attachment.path
+                        to_create.append(values)
+                if to_create:
+                    Share.create(to_create)
             elif action[0] == 'write':
                 Share.write(action[1], action[2])
             elif action[0] == 'delete':
